class Shortcut(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies shortcut keys that can be used by menu items.

 

 enum Shortcut,values: Alt0 (262192),Alt1 (262193),Alt2 (262194),Alt3 (262195),Alt4 (262196),Alt5 (262197),Alt6 (262198),Alt7 (262199),Alt8 (262200),Alt9 (262201),AltBksp (262152),AltDownArrow (262184),AltF1 (262256),AltF10 (262265),AltF11 (262266),AltF12 (262267),AltF2 (262257),AltF3 (262258),AltF4 (262259),AltF5 (262260),AltF6 (262261),AltF7 (262262),AltF8 (262263),AltF9 (262264),AltLeftArrow (262181),AltRightArrow (262183),AltUpArrow (262182),Ctrl0 (131120),Ctrl1 (131121),Ctrl2 (131122),Ctrl3 (131123),Ctrl4 (131124),Ctrl5 (131125),Ctrl6 (131126),Ctrl7 (131127),Ctrl8 (131128),Ctrl9 (131129),CtrlA (131137),CtrlB (131138),CtrlC (131139),CtrlD (131140),CtrlDel (131118),CtrlE (131141),CtrlF (131142),CtrlF1 (131184),CtrlF10 (131193),CtrlF11 (131194),CtrlF12 (131195),CtrlF2 (131185),CtrlF3 (131186),CtrlF4 (131187),CtrlF5 (131188),CtrlF6 (131189),CtrlF7 (131190),CtrlF8 (131191),CtrlF9 (131192),CtrlG (131143),CtrlH (131144),CtrlI (131145),CtrlIns (131117),CtrlJ (131146),CtrlK (131147),CtrlL (131148),CtrlM (131149),CtrlN (131150),CtrlO (131151),CtrlP (131152),CtrlQ (131153),CtrlR (131154),CtrlS (131155),CtrlShift0 (196656),CtrlShift1 (196657),CtrlShift2 (196658),CtrlShift3 (196659),CtrlShift4 (196660),CtrlShift5 (196661),CtrlShift6 (196662),CtrlShift7 (196663),CtrlShift8 (196664),CtrlShift9 (196665),CtrlShiftA (196673),CtrlShiftB (196674),CtrlShiftC (196675),CtrlShiftD (196676),CtrlShiftE (196677),CtrlShiftF (196678),CtrlShiftF1 (196720),CtrlShiftF10 (196729),CtrlShiftF11 (196730),CtrlShiftF12 (196731),CtrlShiftF2 (196721),CtrlShiftF3 (196722),CtrlShiftF4 (196723),CtrlShiftF5 (196724),CtrlShiftF6 (196725),CtrlShiftF7 (196726),CtrlShiftF8 (196727),CtrlShiftF9 (196728),CtrlShiftG (196679),CtrlShiftH (196680),CtrlShiftI (196681),CtrlShiftJ (196682),CtrlShiftK (196683),CtrlShiftL (196684),CtrlShiftM (196685),CtrlShiftN (196686),CtrlShiftO (196687),CtrlShiftP (196688),CtrlShiftQ (196689),CtrlShiftR (196690),CtrlShiftS (196691),CtrlShiftT (196692),CtrlShiftU (196693),CtrlShiftV (196694),CtrlShiftW (196695),CtrlShiftX (196696),CtrlShiftY (196697),CtrlShiftZ (196698),CtrlT (131156),CtrlU (131157),CtrlV (131158),CtrlW (131159),CtrlX (131160),CtrlY (131161),CtrlZ (131162),Del (46),F1 (112),F10 (121),F11 (122),F12 (123),F2 (113),F3 (114),F4 (115),F5 (116),F6 (117),F7 (118),F8 (119),F9 (120),Ins (45),None (0),ShiftDel (65582),ShiftF1 (65648),ShiftF10 (65657),ShiftF11 (65658),ShiftF12 (65659),ShiftF2 (65649),ShiftF3 (65650),ShiftF4 (65651),ShiftF5 (65652),ShiftF6 (65653),ShiftF7 (65654),ShiftF8 (65655),ShiftF9 (65656),ShiftIns (65581)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Alt0=None
 Alt1=None
 Alt2=None
 Alt3=None
 Alt4=None
 Alt5=None
 Alt6=None
 Alt7=None
 Alt8=None
 Alt9=None
 AltBksp=None
 AltDownArrow=None
 AltF1=None
 AltF10=None
 AltF11=None
 AltF12=None
 AltF2=None
 AltF3=None
 AltF4=None
 AltF5=None
 AltF6=None
 AltF7=None
 AltF8=None
 AltF9=None
 AltLeftArrow=None
 AltRightArrow=None
 AltUpArrow=None
 Ctrl0=None
 Ctrl1=None
 Ctrl2=None
 Ctrl3=None
 Ctrl4=None
 Ctrl5=None
 Ctrl6=None
 Ctrl7=None
 Ctrl8=None
 Ctrl9=None
 CtrlA=None
 CtrlB=None
 CtrlC=None
 CtrlD=None
 CtrlDel=None
 CtrlE=None
 CtrlF=None
 CtrlF1=None
 CtrlF10=None
 CtrlF11=None
 CtrlF12=None
 CtrlF2=None
 CtrlF3=None
 CtrlF4=None
 CtrlF5=None
 CtrlF6=None
 CtrlF7=None
 CtrlF8=None
 CtrlF9=None
 CtrlG=None
 CtrlH=None
 CtrlI=None
 CtrlIns=None
 CtrlJ=None
 CtrlK=None
 CtrlL=None
 CtrlM=None
 CtrlN=None
 CtrlO=None
 CtrlP=None
 CtrlQ=None
 CtrlR=None
 CtrlS=None
 CtrlShift0=None
 CtrlShift1=None
 CtrlShift2=None
 CtrlShift3=None
 CtrlShift4=None
 CtrlShift5=None
 CtrlShift6=None
 CtrlShift7=None
 CtrlShift8=None
 CtrlShift9=None
 CtrlShiftA=None
 CtrlShiftB=None
 CtrlShiftC=None
 CtrlShiftD=None
 CtrlShiftE=None
 CtrlShiftF=None
 CtrlShiftF1=None
 CtrlShiftF10=None
 CtrlShiftF11=None
 CtrlShiftF12=None
 CtrlShiftF2=None
 CtrlShiftF3=None
 CtrlShiftF4=None
 CtrlShiftF5=None
 CtrlShiftF6=None
 CtrlShiftF7=None
 CtrlShiftF8=None
 CtrlShiftF9=None
 CtrlShiftG=None
 CtrlShiftH=None
 CtrlShiftI=None
 CtrlShiftJ=None
 CtrlShiftK=None
 CtrlShiftL=None
 CtrlShiftM=None
 CtrlShiftN=None
 CtrlShiftO=None
 CtrlShiftP=None
 CtrlShiftQ=None
 CtrlShiftR=None
 CtrlShiftS=None
 CtrlShiftT=None
 CtrlShiftU=None
 CtrlShiftV=None
 CtrlShiftW=None
 CtrlShiftX=None
 CtrlShiftY=None
 CtrlShiftZ=None
 CtrlT=None
 CtrlU=None
 CtrlV=None
 CtrlW=None
 CtrlX=None
 CtrlY=None
 CtrlZ=None
 Del=None
 F1=None
 F10=None
 F11=None
 F12=None
 F2=None
 F3=None
 F4=None
 F5=None
 F6=None
 F7=None
 F8=None
 F9=None
 Ins=None
 None=None
 ShiftDel=None
 ShiftF1=None
 ShiftF10=None
 ShiftF11=None
 ShiftF12=None
 ShiftF2=None
 ShiftF3=None
 ShiftF4=None
 ShiftF5=None
 ShiftF6=None
 ShiftF7=None
 ShiftF8=None
 ShiftF9=None
 ShiftIns=None
 value__=None




class ErrorEventArgs(EventArgs):
 """
 Provides data for the System.IO.FileSystemWatcher.Error event.

 

 ErrorEventArgs(exception: Exception)
 """
 def GetException(self):
  """
  GetException(self: ErrorEventArgs) -> Exception

  

   Gets the System.Exception that represents the error that occurred.

   Returns: An System.Exception that represents the error that occurred.
  """
  pass
 @staticmethod
 def __new__(self,exception):
  """ __new__(cls: type,exception: Exception) """
  pass



class ListViewVirtualItemsSelectionRangeChangedEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.ListView.VirtualItemsSelectionRangeChanged event.

 

 ListViewVirtualItemsSelectionRangeChangedEventArgs(startIndex: int,endIndex: int,isSelected: bool)
 """
 @staticmethod
 def __new__(self,startIndex,endIndex,isSelected):
  """ __new__(cls: type,startIndex: int,endIndex: int,isSelected: bool) """
  pass
 EndIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the index for the last item in the range of items whose selection state has changed



Get: EndIndex(self: ListViewVirtualItemsSelectionRangeChangedEventArgs) -> int



"""

 IsSelected=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the range of items is selected.



Get: IsSelected(self: ListViewVirtualItemsSelectionRangeChangedEventArgs) -> bool



"""

 StartIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the index for the first item in the range of items whose selection state has changed.



Get: StartIndex(self: ListViewVirtualItemsSelectionRangeChangedEventArgs) -> int



"""





class LicenseContext(object,IServiceProvider):
 """
 Specifies when you can use a licensed object and provides a way of obtaining additional services needed to support licenses running within its domain.

 

 LicenseContext()
 """
 def GetSavedLicenseKey(self,type,resourceAssembly):
  """
  GetSavedLicenseKey(self: LicenseContext,type: Type,resourceAssembly: Assembly) -> str

  

   When overridden in a derived class,returns a saved license key for the specified type,from the 

    specified resource assembly.

  

  

   type: A System.Type that represents the type of component.

   resourceAssembly: An System.Reflection.Assembly with the license key.

   Returns: The System.ComponentModel.License.LicenseKey for the specified type. This method returns null 

    unless you override it.
  """
  pass
 def GetService(self,type):
  """
  GetService(self: LicenseContext,type: Type) -> object

  

   Gets the requested service,if it is available.

  

   type: The type of service to retrieve.

   Returns: An instance of the service,or null if the service cannot be found.
  """
  pass
 def SetSavedLicenseKey(self,type,key):
  """
  SetSavedLicenseKey(self: LicenseContext,type: Type,key: str)

   When overridden in a derived class,sets a license key for the specified type.

  

   type: A System.Type that represents the component associated with the license key.

   key: The System.ComponentModel.License.LicenseKey to save for the type of component.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 UsageMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a derived class,gets a value that specifies when you can use a license.



Get: UsageMode(self: LicenseContext) -> LicenseUsageMode



"""





# encoding: utf-8
# module System.Windows.Input.StylusPlugIns calls itself StylusPlugIns
# from PresentationCore,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class StylusPlugIn(object):
 """ Represents a plug-in that can be added to a control's System.Windows.UIElement.StylusPlugIns property. """
 def OnAdded(self,*args):
  """
  OnAdded(self: StylusPlugIn)

   Occurs when the System.Windows.Input.StylusPlugIns.StylusPlugIn is added to an element.
  """
  pass
 def OnEnabledChanged(self,*args):
  """
  OnEnabledChanged(self: StylusPlugIn)

   Occurs when the System.Windows.Input.StylusPlugIns.StylusPlugIn.Enabled property changes.
  """
  pass
 def OnIsActiveForInputChanged(self,*args):
  """
  OnIsActiveForInputChanged(self: StylusPlugIn)

   Occurs when the System.Windows.Input.StylusPlugIns.StylusPlugIn.IsActiveForInput property 

    changes.
  """
  pass
 def OnRemoved(self,*args):
  """
  OnRemoved(self: StylusPlugIn)

   Occurs when the System.Windows.Input.StylusPlugIns.StylusPlugIn is removed from an element.
  """
  pass
 def OnStylusDown(self,*args):
  """
  OnStylusDown(self: StylusPlugIn,rawStylusInput: RawStylusInput)

   Occurs on a thread in the pen thread pool when the tablet pen touches the digitizer.

  

   rawStylusInput: A System.Windows.Input.StylusPlugIns.RawStylusInput that contains information about input from 

    the pen.
  """
  pass
 def OnStylusDownProcessed(self,*args):
  """
  OnStylusDownProcessed(self: StylusPlugIn,callbackData: object,targetVerified: bool)

   Occurs on the application UI (user interface) thread when the tablet pen touches the digitizer.

  

   callbackData: The object that the application passed to the 

    System.Windows.Input.StylusPlugIns.RawStylusInput.NotifyWhenProcessed(System.Object) method.

  

   targetVerified: true if the pen's input was correctly routed to the 

    System.Windows.Input.StylusPlugIns.StylusPlugIn; otherwise,false.
  """
  pass
 def OnStylusEnter(self,*args):
  """
  OnStylusEnter(self: StylusPlugIn,rawStylusInput: RawStylusInput,confirmed: bool)

   Occurs on a pen thread when the cursor enters the bounds of an element.

  

   rawStylusInput: A System.Windows.Input.StylusPlugIns.RawStylusInput that contains information about input from 

    the pen.

  

   confirmed: true if the pen actually entered the bounds of the element; otherwise,false.
  """
  pass
 def OnStylusLeave(self,*args):
  """
  OnStylusLeave(self: StylusPlugIn,rawStylusInput: RawStylusInput,confirmed: bool)

   Occurs on a pen thread when the cursor leaves the bounds of an element.

  

   rawStylusInput: A System.Windows.Input.StylusPlugIns.RawStylusInput that contains information about input from 

    the pen.

  

   confirmed: true if the pen actually left the bounds of the element; otherwise,false.
  """
  pass
 def OnStylusMove(self,*args):
  """
  OnStylusMove(self: StylusPlugIn,rawStylusInput: RawStylusInput)

   Occurs on a pen thread when the tablet pen moves on the digitizer.

  

   rawStylusInput: A System.Windows.Input.StylusPlugIns.RawStylusInput that contains information about input from 

    the pen.
  """
  pass
 def OnStylusMoveProcessed(self,*args):
  """
  OnStylusMoveProcessed(self: StylusPlugIn,callbackData: object,targetVerified: bool)

   Occurs on the application UI (user interface) thread when the tablet pen moves on the digitizer.

  

   callbackData: The object that the application passed to the 

    System.Windows.Input.StylusPlugIns.RawStylusInput.NotifyWhenProcessed(System.Object) method.

  

   targetVerified: true if the pen's input was correctly routed to the 

    System.Windows.Input.StylusPlugIns.StylusPlugIn; otherwise,false.
  """
  pass
 def OnStylusUp(self,*args):
  """
  OnStylusUp(self: StylusPlugIn,rawStylusInput: RawStylusInput)

   Occurs on a pen thread when the user lifts the tablet pen from the digitizer.

  

   rawStylusInput: A System.Windows.Input.StylusPlugIns.RawStylusInput that contains information about input from 

    the pen.
  """
  pass
 def OnStylusUpProcessed(self,*args):
  """
  OnStylusUpProcessed(self: StylusPlugIn,callbackData: object,targetVerified: bool)

   Occurs on the application UI (user interface) thread when the user lifts the tablet pen from the 

    digitizer.

  

  

   callbackData: The object that the application passed to the 

    System.Windows.Input.StylusPlugIns.RawStylusInput.NotifyWhenProcessed(System.Object) method.

  

   targetVerified: true if the pen's input was correctly routed to the 

    System.Windows.Input.StylusPlugIns.StylusPlugIn; otherwise,false.
  """
  pass
 Element=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.UIElement to which the System.Windows.Input.StylusPlugIns.StylusPlugIn is attached.



Get: Element(self: StylusPlugIn) -> UIElement



"""

 ElementBounds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the cached bounds of the element.



Get: ElementBounds(self: StylusPlugIn) -> Rect



"""

 Enabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether the System.Windows.Input.StylusPlugIns.StylusPlugIn is active.



Get: Enabled(self: StylusPlugIn) -> bool



Set: Enabled(self: StylusPlugIn)=value

"""

 IsActiveForInput=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets whether the System.Windows.Input.StylusPlugIns.StylusPlugIn is able to accept input.



Get: IsActiveForInput(self: StylusPlugIn) -> bool



"""



class DynamicRenderer(StylusPlugIn):
 """
 Draws ink on a surface as the user moves the tablet pen.

 

 DynamicRenderer()
 """
 def GetDispatcher(self,*args):
  """
  GetDispatcher(self: DynamicRenderer) -> Dispatcher

  

   Returns a System.Windows.Threading.Dispatcher for the rendering thread.

   Returns: A System.Windows.Threading.Dispatcher for the rendering thread.
  """
  pass
 def OnDraw(self,*args):
  """
  OnDraw(self: DynamicRenderer,drawingContext: DrawingContext,stylusPoints: StylusPointCollection,geometry: Geometry,fillBrush: Brush)

   Draws the ink in real-time so it appears to "flow" from the tablet pen or other pointing device.

  

   drawingContext: The System.Windows.Media.DrawingContext object onto which the stroke is rendered.

   stylusPoints: The System.Windows.Input.StylusPointCollection that represents the segment of the stroke to draw.

   geometry: A System.Windows.Media.Geometry that represents the path of the mouse pointer.

   fillBrush: A Brush that specifies the appearance of the current stroke.
  """
  pass
 def OnDrawingAttributesReplaced(self,*args):
  """
  OnDrawingAttributesReplaced(self: DynamicRenderer)

   Occurs when the System.Windows.Input.StylusPlugIns.DynamicRenderer.DrawingAttributes property 

    changes.
  """
  pass
 def Reset(self,stylusDevice,stylusPoints):
  """
  Reset(self: DynamicRenderer,stylusDevice: StylusDevice,stylusPoints: StylusPointCollection)

   Clears rendering on the current stroke and redraws it.

  

   stylusDevice: The current stylus device.

   stylusPoints: The stylus points to be redrawn.
  """
  pass
 DrawingAttributes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Windows.Ink.DrawingAttributes that specifies the appearance of the rendered ink.



Get: DrawingAttributes(self: DynamicRenderer) -> DrawingAttributes



Set: DrawingAttributes(self: DynamicRenderer)=value

"""

 RootVisual=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the root visual for the System.Windows.Input.StylusPlugIns.DynamicRenderer.



Get: RootVisual(self: DynamicRenderer) -> Visual



"""



class RawStylusInput(object):
 """ Provides information about input from a System.Windows.Input.StylusDevice to a System.Windows.Input.StylusPlugIns.StylusPlugIn. """
 def GetStylusPoints(self):
  """
  GetStylusPoints(self: RawStylusInput) -> StylusPointCollection

  

   Gets the stylus points that are collected from the stylus.

   Returns: The stylus points that are collected from the stylus.
  """
  pass
 def NotifyWhenProcessed(self,callbackData):
  """
  NotifyWhenProcessed(self: RawStylusInput,callbackData: object)

   Subscribes to the application thread's corresponding stylus methods.

  

   callbackData: The data to pass to the application thread.
  """
  pass
 def SetStylusPoints(self,stylusPoints):
  """
  SetStylusPoints(self: RawStylusInput,stylusPoints: StylusPointCollection)

   Sets the stylus points that are passed to the application thread.

  

   stylusPoints: The stylus points to pass to the application thread.
  """
  pass
 StylusDeviceId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the identifier of the current stylus device.



Get: StylusDeviceId(self: RawStylusInput) -> int



"""

 TabletDeviceId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the identifier of the current tablet device.



Get: TabletDeviceId(self: RawStylusInput) -> int



"""

 Timestamp=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the time at which the input occurred.



Get: Timestamp(self: RawStylusInput) -> int



"""



class StylusPlugInCollection(Collection[StylusPlugIn],IList[StylusPlugIn],ICollection[StylusPlugIn],IEnumerable[StylusPlugIn],IEnumerable,IList,ICollection,IReadOnlyList[StylusPlugIn],IReadOnlyCollection[StylusPlugIn]):
 """ Represent a collection of System.Windows.Input.StylusPlugIns.StylusPlugIn objects. """
 def ClearItems(self,*args):
  """ ClearItems(self: StylusPlugInCollection) """
  pass
 def InsertItem(self,*args):
  """ InsertItem(self: StylusPlugInCollection,index: int,plugIn: StylusPlugIn) """
  pass
 def RemoveItem(self,*args):
  """ RemoveItem(self: StylusPlugInCollection,index: int) """
  pass
 def SetItem(self,*args):
  """ SetItem(self: StylusPlugInCollection,index: int,plugIn: StylusPlugIn) """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Collections.Generic.IList wrapper around the System.Collections.ObjectModel.Collection.



"""






class MeasureItemEventArgs(EventArgs):
 """
 Provides data for the MeasureItem event of the System.Windows.Forms.ListBox,System.Windows.Forms.ComboBox,System.Windows.Forms.CheckedListBox,and System.Windows.Forms.MenuItem controls.

 

 MeasureItemEventArgs(graphics: Graphics,index: int,itemHeight: int)

 MeasureItemEventArgs(graphics: Graphics,index: int)
 """
 @staticmethod
 def __new__(self,graphics,index,itemHeight=None):
  """
  __new__(cls: type,graphics: Graphics,index: int,itemHeight: int)

  __new__(cls: type,graphics: Graphics,index: int)
  """
  pass
 Graphics=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Drawing.Graphics object to measure against.



Get: Graphics(self: MeasureItemEventArgs) -> Graphics



"""

 Index=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the index of the item for which the height and width is needed.



Get: Index(self: MeasureItemEventArgs) -> int



"""

 ItemHeight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the height of the item specified by the System.Windows.Forms.MeasureItemEventArgs.Index.



Get: ItemHeight(self: MeasureItemEventArgs) -> int



Set: ItemHeight(self: MeasureItemEventArgs)=value

"""

 ItemWidth=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the width of the item specified by the System.Windows.Forms.MeasureItemEventArgs.Index.



Get: ItemWidth(self: MeasureItemEventArgs) -> int



Set: ItemWidth(self: MeasureItemEventArgs)=value

"""





class ValidationRule(object):
 """ Provides a way to create a custom rule in order to check the validity of user input. """
 def Validate(self,value,cultureInfo,owner=None):
  """
  Validate(self: ValidationRule,value: object,cultureInfo: CultureInfo,owner: BindingGroup) -> ValidationResult

  Validate(self: ValidationRule,value: object,cultureInfo: CultureInfo,owner: BindingExpressionBase) -> ValidationResult

  Validate(self: ValidationRule,value: object,cultureInfo: CultureInfo) -> ValidationResult

  

   When overridden in a derived class,performs validation checks on a value.

  

   value: The value from the binding target to check.

   cultureInfo: The culture to use in this rule.

   Returns: A System.Windows.Controls.ValidationResult object.
  """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """
  __new__(cls: type)

  __new__(cls: type,validationStep: ValidationStep,validatesOnTargetUpdated: bool)
  """
  pass
 ValidatesOnTargetUpdated=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether the validation rule runs when the target of the System.Windows.Data.Binding is updated.



Get: ValidatesOnTargetUpdated(self: ValidationRule) -> bool



Set: ValidatesOnTargetUpdated(self: ValidationRule)=value

"""

 ValidationStep=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets when the validation rule runs.



Get: ValidationStep(self: ValidationRule) -> ValidationStep



Set: ValidationStep(self: ValidationRule)=value

"""





class ViewBase(DependencyObject):
 """ Represents the base class for views that define the appearance of data in a System.Windows.Controls.ListView control. """
 def ClearItem(self,*args):
  """
  ClearItem(self: ViewBase,item: ListViewItem)

   Removes all bindings and styling that are set for an item.

  

   item: The System.Windows.Controls.ListViewItem to remove settings from.
  """
  pass
 def GetAutomationPeer(self,*args):
  """
  GetAutomationPeer(self: ViewBase,parent: ListView) -> IViewAutomationPeer

  

   Is called when a System.Windows.Controls.ListView control creates a 

    System.Windows.Automation.Peers.ListViewAutomationPeer for its 

    System.Windows.Controls.ListView.View.

  

  

   parent: The System.Windows.Controls.ListView control to use to create the 

    System.Windows.Automation.Peers.ListViewAutomationPeer.

  

   Returns: The System.Windows.Automation.Peers.IViewAutomationPeer interface that implements the 

    System.Windows.Automation.Peers.ListViewAutomationPeer for a custom 

    System.Windows.Controls.ListView.View.
  """
  pass
 def PrepareItem(self,*args):
  """
  PrepareItem(self: ViewBase,item: ListViewItem)

   Prepares an item in the view for display,by setting bindings and styles.

  

   item: The item to prepare for display.
  """
  pass
 DefaultStyleKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the object that is associated with the style for the view mode.



"""

 ItemContainerDefaultStyleKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the style to use for the items in the view mode.



"""





class RegistrationClassContext(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the set of execution contexts in which a class object will be made available for requests to construct instances.

 

 enum (flags) RegistrationClassContext,values: DisableActivateAsActivator (32768),EnableActivateAsActivator (65536),EnableCodeDownload (8192),FromDefaultContext (131072),InProcessHandler (2),InProcessHandler16 (32),InProcessServer (1),InProcessServer16 (8),LocalServer (4),NoCodeDownload (1024),NoCustomMarshal (4096),NoFailureLog (16384),RemoteServer (16),Reserved1 (64),Reserved2 (128),Reserved3 (256),Reserved4 (512),Reserved5 (2048)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 DisableActivateAsActivator=None
 EnableActivateAsActivator=None
 EnableCodeDownload=None
 FromDefaultContext=None
 InProcessHandler=None
 InProcessHandler16=None
 InProcessServer=None
 InProcessServer16=None
 LocalServer=None
 NoCodeDownload=None
 NoCustomMarshal=None
 NoFailureLog=None
 RemoteServer=None
 Reserved1=None
 Reserved2=None
 Reserved3=None
 Reserved4=None
 Reserved5=None
 value__=None




from typing import Tuple, Set, Iterable, List


class RevitAPIEventArgs:
    @property
    def Cancellable(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsCancelled(self) -> bool: ...
    def Dispose(self) -> None: ...


class RevitAPIPreEventArgs(RevitAPIEventArgs):
    def Cancel(self) -> None: ...


class RevitAPIPostEventArgs(RevitAPIEventArgs):
    @property
    def Status(self) -> RevitAPIEventStatus: ...


class RevitAPISingleEventArgs(RevitAPIEventArgs):


class RevitAPIPreDocEventArgs(RevitAPIPreEventArgs):
    @property
    def Document(self) -> Document: ...


class RevitAPIPostDocEventArgs(RevitAPIPostEventArgs):
    @property
    def Document(self) -> Document: ...


class ApplicationInitializedEventArgs(RevitAPISingleEventArgs):


class DocumentClosingEventArgs(RevitAPIPreDocEventArgs):
    @property
    def DocumentId(self) -> int: ...


class DocumentClosedEventArgs(RevitAPIPostEventArgs):
    @property
    def DocumentId(self) -> int: ...


class DocumentPrintingEventArgs(RevitAPIPreDocEventArgs):
    def GetViewElementIds(self) -> List[ElementId]: ...
    def GetSettings(self) -> IPrintSetting: ...


class DocumentPrintedEventArgs(RevitAPIPostDocEventArgs):
    def GetPrintedViewElementIds(self) -> List[ElementId]: ...
    def GetFailedViewElementIds(self) -> List[ElementId]: ...


class ViewPrintingEventArgs(RevitAPIPreDocEventArgs):
    @property
    def Index(self) -> int: ...
    @property
    def TotalViews(self) -> int: ...
    @property
    def View(self) -> View: ...
    def GetSettings(self) -> IPrintSetting: ...


class ViewPrintedEventArgs(RevitAPIPostDocEventArgs):
    @property
    def Index(self) -> int: ...
    @property
    def TotalViews(self) -> int: ...
    @property
    def View(self) -> View: ...


class DocumentSavingEventArgs(RevitAPIPreDocEventArgs):


class DocumentSavedEventArgs(RevitAPIPostDocEventArgs):


class DocumentSavingAsEventArgs(RevitAPIPreDocEventArgs):
    @property
    def PathName(self) -> str: ...
    @property
    def IsSavingAsCentralFile(self) -> bool: ...
    @property
    def IsSavingAsMasterFile(self) -> bool: ...


class DocumentSavedAsEventArgs(RevitAPIPostDocEventArgs):
    @property
    def OriginalPath(self) -> str: ...
    @property
    def IsSavingAsCentralFile(self) -> bool: ...
    @property
    def IsSavingAsMasterFile(self) -> bool: ...


class DocumentSynchronizingWithCentralEventArgs(RevitAPIPreDocEventArgs):
    @property
    def Location(self) -> str: ...
    @property
    def Comments(self) -> str: ...
    @property
    def Options(self) -> SynchronizeWithCentralOptions: ...


class DocumentSynchronizedWithCentralEventArgs(RevitAPIPostDocEventArgs):


class RevitEventArgs:
    @property
    def Cancel(self) -> bool: ...
    @Cancel.setter
    def Cancel(self, value: bool) -> None: ...
    @property
    def Cancellable(self) -> bool: ...


class PreEventArgs(RevitEventArgs):


class PreDocEventArgs(PreEventArgs):
    @property
    def Document(self) -> Document: ...


class PostEventArgs(RevitEventArgs):
    @property
    def Status(self) -> EventStatus: ...


class PostDocEventArgs(PostEventArgs):
    @property
    def Document(self) -> Document: ...


class RevitAPIEventStatus:
    Succeeded = 0
    Cancelled = 1
    Failed = -1


class EventStatus:
    Succeeded = 0
    Cancelled = 1
    Failed = -1


class DocumentChangedEventArgs(RevitAPISingleEventArgs):
    @property
    def Operation(self) -> UndoOperation: ...
    @overload
    def GetAddedElementIds(self, filter: ElementFilter) -> ICollection: ...
    @overload
    def GetAddedElementIds(self) -> ICollection: ...
    def GetDeletedElementIds(self) -> ICollection: ...
    @overload
    def GetModifiedElementIds(self, filter: ElementFilter) -> ICollection: ...
    @overload
    def GetModifiedElementIds(self) -> ICollection: ...
    def GetDocument(self) -> Document: ...
    def GetTransactionNames(self) -> List[str]: ...


class DocumentCreatingEventArgs(RevitAPIPreEventArgs):
    @property
    def Template(self) -> str: ...
    @property
    def DocumentType(self) -> DocumentType: ...


class DocumentCreatedEventArgs(RevitAPIPostDocEventArgs):


class DocumentOpeningEventArgs(RevitAPIPreEventArgs):
    @property
    def PathName(self) -> str: ...
    @property
    def DocumentType(self) -> DocumentType: ...


class DocumentOpenedEventArgs(RevitAPIPostDocEventArgs):


class DocumentWorksharingEnabledEventArgs(RevitAPISingleEventArgs):
    def GetDocument(self) -> Document: ...


class ElementTypeDuplicatingEventArgs(RevitAPIPreDocEventArgs):
    @property
    def ElementTypeId(self) -> ElementId: ...


class ElementTypeDuplicatedEventArgs(RevitAPIPostDocEventArgs):
    @property
    def OriginalElementTypeId(self) -> ElementId: ...
    @property
    def NewName(self) -> str: ...
    @property
    def NewElementTypeId(self) -> ElementId: ...


class FailuresProcessingEventArgs(RevitAPISingleEventArgs):
    def SetProcessingResult(self, result: FailureProcessingResult) -> None: ...
    def GetProcessingResult(self) -> FailureProcessingResult: ...
    def GetFailuresAccessor(self) -> FailuresAccessor: ...


class FamilyLoadingIntoDocumentEventArgs(RevitAPIPreDocEventArgs):
    @property
    def FamilyName(self) -> str: ...
    @property
    def FamilyPath(self) -> str: ...


class FamilyLoadedIntoDocumentEventArgs(RevitAPIPostDocEventArgs):
    @property
    def FamilyName(self) -> str: ...
    @property
    def FamilyPath(self) -> str: ...
    @property
    def OriginalFamilyId(self) -> ElementId: ...
    @property
    def NewFamilyId(self) -> ElementId: ...


class FileImportingEventArgs(RevitAPIPreDocEventArgs):
    @property
    def Path(self) -> str: ...
    @property
    def Format(self) -> ImportExportFileFormat: ...


class FileImportedEventArgs(RevitAPIPostDocEventArgs):
    @property
    def Path(self) -> str: ...
    @property
    def Format(self) -> ImportExportFileFormat: ...
    @property
    def ImportedInstanceId(self) -> ElementId: ...


class FileExportingEventArgs(RevitAPIPreDocEventArgs):
    @property
    def Path(self) -> str: ...
    @property
    def Format(self) -> ImportExportFileFormat: ...


class FileExportedEventArgs(RevitAPIPostDocEventArgs):
    @property
    def Path(self) -> str: ...
    @property
    def Format(self) -> ImportExportFileFormat: ...


class ViewExportingEventArgs(RevitAPIPreDocEventArgs):
    @property
    def ViewId(self) -> ElementId: ...


class ViewExportedEventArgs(RevitAPIPostDocEventArgs):
    @property
    def ViewId(self) -> ElementId: ...


class ViewsExportingByContextEventArgs(RevitAPIPreDocEventArgs):
    def GetViewIds(self) -> List[ElementId]: ...


class ViewsExportedByContextEventArgs(RevitAPIPostDocEventArgs):
    def GetViewIds(self) -> List[ElementId]: ...


class LinkedResourceOpeningEventArgs(RevitAPIPreEventArgs):
    @property
    def ResourceType(self) -> ExternalResourceType: ...
    @property
    def LinkedResourcePathName(self) -> str: ...


class LinkedResourceOpenedEventArgs(RevitAPIPostDocEventArgs):
    @property
    def ResourceType(self) -> ExternalResourceType: ...
    @property
    def LinkedResourcePathName(self) -> str: ...


class ProgressChangedEventArgs(RevitAPISingleEventArgs):
    @property
    def Stage(self) -> ProgressStage: ...
    @property
    def Position(self) -> int: ...
    @property
    def LowerRange(self) -> int: ...
    @property
    def UpperRange(self) -> int: ...
    @property
    def Caption(self) -> str: ...
    def Cancel(self) -> None: ...


class DocumentReloadingLatestEventArgs(RevitAPIPreDocEventArgs):


class DocumentReloadedLatestEventArgs(RevitAPIPostDocEventArgs):
    @property
    def Location(self) -> str: ...
    @Location.setter
    def Location(self, location: str) -> None: ...


class WorksharedOperationProgressChangedEventArgs(RevitAPISingleEventArgs):
    @property
    def Location(self) -> str: ...
    @property
    def Status(self) -> RevitAPIEventStatus: ...


class DocumentSaveToLocalProgressChangedEventArgs(WorksharedOperationProgressChangedEventArgs):
    @property
    def BeforeSaveToCentral(self) -> bool: ...
    @property
    def FinishedStreams(self) -> int: ...
    @property
    def TotalStreams(self) -> int: ...
    @property
    def SaveToLocalFinished(self) -> bool: ...


class DataTransferProgressChangedEventArgs(WorksharedOperationProgressChangedEventArgs):
    @property
    def TransferMode(self) -> DataTransferMode: ...
    @property
    def Speed(self) -> float: ...
    @property
    def FinishedSize(self) -> float: ...
    @property
    def TotalSize(self) -> float: ...


class DocumentReloadLatestProgressChangedEventArgs(DataTransferProgressChangedEventArgs):
    @property
    def RetryTimes(self) -> int: ...
    @property
    def IsMerging(self) -> bool: ...
    @property
    def ReloadLatestFinished(self) -> bool: ...


class DocumentSaveToCentralProgressChangedEventArgs(DataTransferProgressChangedEventArgs):
    @property
    def RetryTimes(self) -> int: ...
    @property
    def SaveToCentralFinished(self) -> bool: ...
    @property
    def FailureDueToConflicts(self) -> bool: ...


class CreateRelatedFileProgressChangedEventArgs(DataTransferProgressChangedEventArgs):
    @property
    def CreatingCloudSharedLocal(self) -> bool: ...
    @property
    def FullDownload(self) -> bool: ...
    @property
    def DownloadFinished(self) -> bool: ...


class UndoOperation:
    TransactionCommitted = 0
    TransactionRolledBack = 1
    TransactionGroupRolledBack = 2
    TransactionUndone = 3
    TransactionRedone = 4


class ProgressStage:
    Started = 0
    RangeChanged = 1
    PositionChanged = 2
    CaptionChanged = 3
    Unchanged = 4
    Finished = 5


class DataTransferMode:
    Download = 0
    Upload = 1
    Undefined = -1



class ScrollEventType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the type of action used to raise the System.Windows.Forms.ScrollBar.Scroll event.

 

 enum ScrollEventType,values: EndScroll (8),First (6),LargeDecrement (2),LargeIncrement (3),Last (7),SmallDecrement (0),SmallIncrement (1),ThumbPosition (4),ThumbTrack (5)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 EndScroll=None
 First=None
 LargeDecrement=None
 LargeIncrement=None
 Last=None
 SmallDecrement=None
 SmallIncrement=None
 ThumbPosition=None
 ThumbTrack=None
 value__=None




class ItemDragEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.ListView.ItemDrag event of the System.Windows.Forms.ListView and System.Windows.Forms.TreeView controls.

 

 ItemDragEventArgs(button: MouseButtons)

 ItemDragEventArgs(button: MouseButtons,item: object)
 """
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 @staticmethod
 def __new__(self,button,item=None):
  """
  __new__(cls: type,button: MouseButtons)

  __new__(cls: type,button: MouseButtons,item: object)
  """
  pass
 Button=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates which mouse buttons were pressed during the drag operation.



Get: Button(self: ItemDragEventArgs) -> MouseButtons



"""

 Item=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the item that is being dragged.



Get: Item(self: ItemDragEventArgs) -> object



"""





class DataGridViewBand(DataGridViewElement,ICloneable,IDisposable):
 """ Represents a linear collection of elements in a System.Windows.Forms.DataGridView control. """
 def Clone(self):
  """
  Clone(self: DataGridViewBand) -> object

  

   Creates an exact copy of this band.

   Returns: An System.Object that represents the cloned System.Windows.Forms.DataGridViewBand.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: DataGridViewBand)

   Releases all resources used by the System.Windows.Forms.DataGridViewBand.
  """
  pass
 def OnDataGridViewChanged(self,*args):
  """
  OnDataGridViewChanged(self: DataGridViewBand)

   Called when the band is associated with a different System.Windows.Forms.DataGridView.
  """
  pass
 def RaiseCellClick(self,*args):
  """
  RaiseCellClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellContentClick(self,*args):
  """
  RaiseCellContentClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellContentClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellContentDoubleClick(self,*args):
  """
  RaiseCellContentDoubleClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellContentDoubleClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellValueChanged(self,*args):
  """
  RaiseCellValueChanged(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellValueChanged event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseDataError(self,*args):
  """
  RaiseDataError(self: DataGridViewElement,e: DataGridViewDataErrorEventArgs)

   Raises the System.Windows.Forms.DataGridView.DataError event.

  

   e: A System.Windows.Forms.DataGridViewDataErrorEventArgs that contains the event data.
  """
  pass
 def RaiseMouseWheel(self,*args):
  """
  RaiseMouseWheel(self: DataGridViewElement,e: MouseEventArgs)

   Raises the System.Windows.Forms.Control.MouseWheel event.

  

   e: A System.Windows.Forms.MouseEventArgs that contains the event data.
  """
  pass
 def ToString(self):
  """
  ToString(self: DataGridViewBand) -> str

  

   Returns a string that represents the current band.

   Returns: A System.String that represents the current System.Windows.Forms.DataGridViewBand.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 ContextMenuStrip=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the shortcut menu for the band.



Get: ContextMenuStrip(self: DataGridViewBand) -> ContextMenuStrip



Set: ContextMenuStrip(self: DataGridViewBand)=value

"""

 DefaultCellStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the default cell style of the band.



Get: DefaultCellStyle(self: DataGridViewBand) -> DataGridViewCellStyle



Set: DefaultCellStyle(self: DataGridViewBand)=value

"""

 DefaultHeaderCellType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the run-time type of the default header cell.



Get: DefaultHeaderCellType(self: DataGridViewBand) -> Type



Set: DefaultHeaderCellType(self: DataGridViewBand)=value

"""

 Displayed=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the band is currently displayed onscreen.



Get: Displayed(self: DataGridViewBand) -> bool



"""

 Frozen=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the band will move when a user scrolls through the System.Windows.Forms.DataGridView.



Get: Frozen(self: DataGridViewBand) -> bool



Set: Frozen(self: DataGridViewBand)=value

"""

 HasDefaultCellStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the System.Windows.Forms.DataGridViewBand.DefaultCellStyle property has been set.



Get: HasDefaultCellStyle(self: DataGridViewBand) -> bool



"""

 HeaderCellCore=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the header cell of the System.Windows.Forms.DataGridViewBand.



"""

 Index=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the relative position of the band within the System.Windows.Forms.DataGridView control.



Get: Index(self: DataGridViewBand) -> int



"""

 InheritedStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the cell style in effect for the current band,taking into account style inheritance.



Get: InheritedStyle(self: DataGridViewBand) -> DataGridViewCellStyle



"""

 IsRow=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the band represents a row.



"""

 ReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the user can edit the band's cells.



Get: ReadOnly(self: DataGridViewBand) -> bool



Set: ReadOnly(self: DataGridViewBand)=value

"""

 Resizable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the band can be resized in the user interface (UI).



Get: Resizable(self: DataGridViewBand) -> DataGridViewTriState



Set: Resizable(self: DataGridViewBand)=value

"""

 Selected=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the band is in a selected user interface (UI) state.



Get: Selected(self: DataGridViewBand) -> bool



Set: Selected(self: DataGridViewBand)=value

"""

 Tag=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the object that contains data to associate with the band.



Get: Tag(self: DataGridViewBand) -> object



Set: Tag(self: DataGridViewBand)=value

"""

 Visible=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the band is visible to the user.



Get: Visible(self: DataGridViewBand) -> bool



Set: Visible(self: DataGridViewBand)=value

"""





class ObjectDisposedException(InvalidOperationException,ISerializable,_Exception):
 """
 The exception that is thrown when an operation is performed on a disposed object.

 

 ObjectDisposedException(objectName: str)

 ObjectDisposedException(objectName: str,message: str)

 ObjectDisposedException(message: str,innerException: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def GetObjectData(self,info,context):
  """
  GetObjectData(self: ObjectDisposedException,info: SerializationInfo,context: StreamingContext)

   Retrieves the System.Runtime.Serialization.SerializationInfo object with the parameter name and 

    additional exception information.

  

  

   info: The System.Runtime.Serialization.SerializationInfo that holds the serialized object data about 

    the exception being thrown.

  

   context: The System.Runtime.Serialization.StreamingContext that contains contextual information about the 

    source or destination.
  """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,objectName: str)

  __new__(cls: type,objectName: str,message: str)

  __new__(cls: type,message: str,innerException: Exception)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Message=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the message that describes the error.



Get: Message(self: ObjectDisposedException) -> str



"""

 ObjectName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the disposed object.



Get: ObjectName(self: ObjectDisposedException) -> str



"""





class DataGridViewCellContextMenuStripNeededEventArgs(DataGridViewCellEventArgs):
 """
 Provides data for the System.Windows.Forms.DataGridView.CellContextMenuStripNeeded event.

 

 DataGridViewCellContextMenuStripNeededEventArgs(columnIndex: int,rowIndex: int)
 """
 @staticmethod
 def __new__(self,columnIndex,rowIndex):
  """ __new__(cls: type,columnIndex: int,rowIndex: int) """
  pass
 ContextMenuStrip=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the shortcut menu for the cell that raised the System.Windows.Forms.DataGridView.CellContextMenuStripNeeded event.



Get: ContextMenuStrip(self: DataGridViewCellContextMenuStripNeededEventArgs) -> ContextMenuStrip



Set: ContextMenuStrip(self: DataGridViewCellContextMenuStripNeededEventArgs)=value

"""





class AllowReversePInvokeCallsAttribute(Attribute,_Attribute):
 """
 Allows an unmanaged method to call a managed method.

 

 AllowReversePInvokeCallsAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class TreeNodeConverter(TypeConverter):
 """
 Provides a type converter to convert System.Windows.Forms.TreeNode objects to and from various other representations.

 

 TreeNodeConverter()
 """
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: TreeNodeConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Gets a value indicating whether this converter can convert an object to the given destination 

    type using the context.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   destinationType: A System.Type that represents the type you wish to convert to.

   Returns: true if this converter can perform the conversion; otherwise,false.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: TreeNodeConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: A System.Globalization.CultureInfo. If null is passed,the current culture is assumed.

   value: The System.Object to convert.

   destinationType: The System.Type to convert the value parameter to.

   Returns: An System.Object that represents the converted value.
  """
  pass



class WebClient(Component,IComponent,IDisposable):
 """
 Provides common methods for sending data to and receiving data from a resource identified by a URI.

 

 WebClient()
 """
 def CancelAsync(self):
  """
  CancelAsync(self: WebClient)

   Cancels a pending asynchronous operation.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: Component,disposing: bool)

   Releases the unmanaged resources used by the System.ComponentModel.Component and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def DownloadData(self,address):
  """
  DownloadData(self: WebClient,address: Uri) -> Array[Byte]

  

   Downloads the resource with the specified URI as a System.Byte array.

  

   address: The URI represented by the System.Uri  object,from which to download data.

   Returns: A System.Byte array containing the downloaded resource.

  DownloadData(self: WebClient,address: str) -> Array[Byte]

  

   Downloads the resource with the specified URI as a System.Byte array.

  

   address: The URI from which to download data.

   Returns: A System.Byte array containing the downloaded resource.
  """
  pass
 def DownloadDataAsync(self,address,userToken=None):
  """
  DownloadDataAsync(self: WebClient,address: Uri,userToken: object)

   Downloads the specified resource as a System.Byte array. This method does not block the calling 

    thread.

  

  

   address: A System.Uri containing the URI to download.

   userToken: A user-defined object that is passed to the method invoked when the asynchronous operation 

    completes.

  

  DownloadDataAsync(self: WebClient,address: Uri)

   Downloads the specified resource as a System.Byte array. This method does not block the calling 

    thread.

  

  

   address: A System.Uri containing the URI to download.
  """
  pass
 def DownloadDataTaskAsync(self,address):
  """
  DownloadDataTaskAsync(self: WebClient,address: Uri) -> Task[Array[Byte]]

  DownloadDataTaskAsync(self: WebClient,address: str) -> Task[Array[Byte]]
  """
  pass
 def DownloadFile(self,address,fileName):
  """
  DownloadFile(self: WebClient,address: Uri,fileName: str)

   Downloads the resource with the specified URI to a local file.

  

   address: The URI specified as a System.String,from which to download data.

   fileName: The name of the local file that is to receive the data.

  DownloadFile(self: WebClient,address: str,fileName: str)

   Downloads the resource with the specified URI to a local file.

  

   address: The URI from which to download data.

   fileName: The name of the local file that is to receive the data.
  """
  pass
 def DownloadFileAsync(self,address,fileName,userToken=None):
  """
  DownloadFileAsync(self: WebClient,address: Uri,fileName: str,userToken: object)

   Downloads,to a local file,the resource with the specified URI. This method does not block the 

    calling thread.

  

  

   address: The URI of the resource to download.

   fileName: The name of the file to be placed on the local computer.

   userToken: A user-defined object that is passed to the method invoked when the asynchronous operation 

    completes.

  

  DownloadFileAsync(self: WebClient,address: Uri,fileName: str)

   Downloads,to a local file,the resource with the specified URI. This method does not block the 

    calling thread.

  

  

   address: The URI of the resource to download.

   fileName: The name of the file to be placed on the local computer.
  """
  pass
 def DownloadFileTaskAsync(self,address,fileName):
  """
  DownloadFileTaskAsync(self: WebClient,address: Uri,fileName: str) -> Task

  DownloadFileTaskAsync(self: WebClient,address: str,fileName: str) -> Task
  """
  pass
 def DownloadString(self,address):
  """
  DownloadString(self: WebClient,address: Uri) -> str

  

   Downloads the requested resource as a System.String. The resource to download is specified as a 

    System.Uri.

  

  

   address: A System.Uri object containing the URI to download.

   Returns: A System.String containing the requested resource.

  DownloadString(self: WebClient,address: str) -> str

  

   Downloads the requested resource as a System.String. The resource to download is specified as a 

    System.String containing the URI.

  

  

   address: A System.String containing the URI to download.

   Returns: A System.String containing the requested resource.
  """
  pass
 def DownloadStringAsync(self,address,userToken=None):
  """
  DownloadStringAsync(self: WebClient,address: Uri,userToken: object)

   Downloads the specified string to the specified resource. This method does not block the calling 

    thread.

  

  

   address: A System.Uri containing the URI to download.

   userToken: A user-defined object that is passed to the method invoked when the asynchronous operation 

    completes.

  

  DownloadStringAsync(self: WebClient,address: Uri)

   Downloads the resource specified as a System.Uri. This method does not block the calling thread.

  

   address: A System.Uri containing the URI to download.
  """
  pass
 def DownloadStringTaskAsync(self,address):
  """
  DownloadStringTaskAsync(self: WebClient,address: Uri) -> Task[str]

  DownloadStringTaskAsync(self: WebClient,address: str) -> Task[str]
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def GetWebRequest(self,*args):
  """
  GetWebRequest(self: WebClient,address: Uri) -> WebRequest

  

   Returns a System.Net.WebRequest object for the specified resource.

  

   address: A System.Uri that identifies the resource to request.

   Returns: A new System.Net.WebRequest object for the specified resource.
  """
  pass
 def GetWebResponse(self,*args):
  """
  GetWebResponse(self: WebClient,request: WebRequest,result: IAsyncResult) -> WebResponse

  

   Returns the System.Net.WebResponse for the specified System.Net.WebRequest using the specified 

    System.IAsyncResult.

  

  

   request: A System.Net.WebRequest that is used to obtain the response.

   result: An System.IAsyncResult object obtained from a previous call to 

    System.Net.WebRequest.BeginGetResponse(System.AsyncCallback,System.Object) .

  

   Returns: A System.Net.WebResponse containing the response for the specified System.Net.WebRequest.

  GetWebResponse(self: WebClient,request: WebRequest) -> WebResponse

  

   Returns the System.Net.WebResponse for the specified System.Net.WebRequest.

  

   request: A System.Net.WebRequest that is used to obtain the response.

   Returns: A System.Net.WebResponse containing the response for the specified System.Net.WebRequest.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnDownloadDataCompleted(self,*args):
  """
  OnDownloadDataCompleted(self: WebClient,e: DownloadDataCompletedEventArgs)

   Raises the System.Net.WebClient.DownloadDataCompleted event.

  

   e: A System.Net.DownloadDataCompletedEventArgs object that contains event data.
  """
  pass
 def OnDownloadFileCompleted(self,*args):
  """
  OnDownloadFileCompleted(self: WebClient,e: AsyncCompletedEventArgs)

   Raises the System.Net.WebClient.DownloadFileCompleted event.

  

   e: An System.ComponentModel.AsyncCompletedEventArgs object containing event data.
  """
  pass
 def OnDownloadProgressChanged(self,*args):
  """
  OnDownloadProgressChanged(self: WebClient,e: DownloadProgressChangedEventArgs)

   Raises the System.Net.WebClient.DownloadProgressChanged event.

  

   e: A System.Net.DownloadProgressChangedEventArgs object containing event data.
  """
  pass
 def OnDownloadStringCompleted(self,*args):
  """
  OnDownloadStringCompleted(self: WebClient,e: DownloadStringCompletedEventArgs)

   Raises the System.Net.WebClient.DownloadStringCompleted event.

  

   e: A System.Net.DownloadStringCompletedEventArgs object containing event data.
  """
  pass
 def OnOpenReadCompleted(self,*args):
  """
  OnOpenReadCompleted(self: WebClient,e: OpenReadCompletedEventArgs)

   Raises the System.Net.WebClient.OpenReadCompleted event.

  

   e: A System.Net.OpenReadCompletedEventArgs  object containing event data.
  """
  pass
 def OnOpenWriteCompleted(self,*args):
  """
  OnOpenWriteCompleted(self: WebClient,e: OpenWriteCompletedEventArgs)

   Raises the System.Net.WebClient.OpenWriteCompleted event.

  

   e: A System.Net.OpenWriteCompletedEventArgs object containing event data.
  """
  pass
 def OnUploadDataCompleted(self,*args):
  """
  OnUploadDataCompleted(self: WebClient,e: UploadDataCompletedEventArgs)

   Raises the System.Net.WebClient.UploadDataCompleted event.

  

   e: A System.Net.UploadDataCompletedEventArgs  object containing event data.
  """
  pass
 def OnUploadFileCompleted(self,*args):
  """
  OnUploadFileCompleted(self: WebClient,e: UploadFileCompletedEventArgs)

   Raises the System.Net.WebClient.UploadFileCompleted event.

  

   e: An System.Net.UploadFileCompletedEventArgs object containing event data.
  """
  pass
 def OnUploadProgressChanged(self,*args):
  """
  OnUploadProgressChanged(self: WebClient,e: UploadProgressChangedEventArgs)

   Raises the System.Net.WebClient.UploadProgressChanged event.

  

   e: An System.Net.UploadProgressChangedEventArgs object containing event data.
  """
  pass
 def OnUploadStringCompleted(self,*args):
  """
  OnUploadStringCompleted(self: WebClient,e: UploadStringCompletedEventArgs)

   Raises the System.Net.WebClient.UploadStringCompleted event.

  

   e: An System.Net.UploadStringCompletedEventArgs  object containing event data.
  """
  pass
 def OnUploadValuesCompleted(self,*args):
  """
  OnUploadValuesCompleted(self: WebClient,e: UploadValuesCompletedEventArgs)

   Raises the System.Net.WebClient.UploadValuesCompleted event.

  

   e: A System.Net.UploadValuesCompletedEventArgs  object containing event data.
  """
  pass
 def OnWriteStreamClosed(self,*args):
  """ OnWriteStreamClosed(self: WebClient,e: WriteStreamClosedEventArgs) """
  pass
 def OpenRead(self,address):
  """
  OpenRead(self: WebClient,address: Uri) -> Stream

  

   Opens a readable stream for the data downloaded from a resource with the URI specified as a 

    System.Uri

  

  

   address: The URI specified as a System.Uri from which to download data.

   Returns: A System.IO.Stream used to read data from a resource.

  OpenRead(self: WebClient,address: str) -> Stream

  

   Opens a readable stream for the data downloaded from a resource with the URI specified as a 

    System.String.

  

  

   address: The URI specified as a System.String from which to download data.

   Returns: A System.IO.Stream used to read data from a resource.
  """
  pass
 def OpenReadAsync(self,address,userToken=None):
  """
  OpenReadAsync(self: WebClient,address: Uri,userToken: object)

   Opens a readable stream containing the specified resource. This method does not block the 

    calling thread.

  

  

   address: The URI of the resource to retrieve.

   userToken: A user-defined object that is passed to the method invoked when the asynchronous operation 

    completes.

  

  OpenReadAsync(self: WebClient,address: Uri)

   Opens a readable stream containing the specified resource. This method does not block the 

    calling thread.

  

  

   address: The URI of the resource to retrieve.
  """
  pass
 def OpenReadTaskAsync(self,address):
  """
  OpenReadTaskAsync(self: WebClient,address: Uri) -> Task[Stream]

  OpenReadTaskAsync(self: WebClient,address: str) -> Task[Stream]
  """
  pass
 def OpenWrite(self,address,method=None):
  """
  OpenWrite(self: WebClient,address: str,method: str) -> Stream

  

   Opens a stream for writing data to the specified resource,using the specified method.

  

   address: The URI of the resource to receive the data.

   method: The method used to send the data to the resource. If null,the default is POST for http and STOR 

    for ftp.

  

   Returns: A System.IO.Stream used to write data to the resource.

  OpenWrite(self: WebClient,address: Uri,method: str) -> Stream

  

   Opens a stream for writing data to the specified resource,by using the specified method.

  

   address: The URI of the resource to receive the data.

   method: The method used to send the data to the resource. If null,the default is POST for http and STOR 

    for ftp.

  

   Returns: A System.IO.Stream used to write data to the resource.

  OpenWrite(self: WebClient,address: str) -> Stream

  

   Opens a stream for writing data to the specified resource.

  

   address: The URI of the resource to receive the data.

   Returns: A System.IO.Stream used to write data to the resource.

  OpenWrite(self: WebClient,address: Uri) -> Stream

  

   Opens a stream for writing data to the specified resource.

  

   address: The URI of the resource to receive the data.

   Returns: A System.IO.Stream used to write data to the resource.
  """
  pass
 def OpenWriteAsync(self,address,method=None,userToken=None):
  """
  OpenWriteAsync(self: WebClient,address: Uri,method: str,userToken: object)

   Opens a stream for writing data to the specified resource,using the specified method. This 

    method does not block the calling thread.

  

  

   address: The URI of the resource to receive the data.

   method: The method used to send the data to the resource. If null,the default is POST for http and STOR 

    for ftp.

  

   userToken: A user-defined object that is passed to the method invoked when the asynchronous operation 

    completes

  

  OpenWriteAsync(self: WebClient,address: Uri,method: str)

   Opens a stream for writing data to the specified resource. This method does not block the 

    calling thread.

  

  

   address: The URI of the resource to receive the data.

   method: The method used to send the data to the resource. If null,the default is POST for http and STOR 

    for ftp.

  

  OpenWriteAsync(self: WebClient,address: Uri)

   Opens a stream for writing data to the specified resource. This method does not block the 

    calling thread.

  

  

   address: The URI of the resource to receive the data.
  """
  pass
 def OpenWriteTaskAsync(self,address,method=None):
  """
  OpenWriteTaskAsync(self: WebClient,address: str,method: str) -> Task[Stream]

  OpenWriteTaskAsync(self: WebClient,address: Uri,method: str) -> Task[Stream]

  OpenWriteTaskAsync(self: WebClient,address: str) -> Task[Stream]

  OpenWriteTaskAsync(self: WebClient,address: Uri) -> Task[Stream]
  """
  pass
 def UploadData(self,address,*__args):
  """
  UploadData(self: WebClient,address: str,method: str,data: Array[Byte]) -> Array[Byte]

  

   Uploads a data buffer to the specified resource,using the specified method.

  

   address: The URI of the resource to receive the data.

   method: The HTTP method used to send the data to the resource. If null,the default is POST for http and 

    STOR for ftp.

  

   data: The data buffer to send to the resource.

   Returns: A System.Byte array containing the body of the response from the resource.

  UploadData(self: WebClient,address: Uri,method: str,data: Array[Byte]) -> Array[Byte]

  

   Uploads a data buffer to the specified resource,using the specified method.

  

   address: The URI of the resource to receive the data.

   method: The HTTP method used to send the data to the resource. If null,the default is POST for http and 

    STOR for ftp.

  

   data: The data buffer to send to the resource.

   Returns: A System.Byte array containing the body of the response from the resource.

  UploadData(self: WebClient,address: str,data: Array[Byte]) -> Array[Byte]

  

   Uploads a data buffer to a resource identified by a URI.

  

   address: The URI of the resource to receive the data.

   data: The data buffer to send to the resource.

   Returns: A System.Byte array containing the body of the response from the resource.

  UploadData(self: WebClient,address: Uri,data: Array[Byte]) -> Array[Byte]

  

   Uploads a data buffer to a resource identified by a URI.

  

   address: The URI of the resource to receive the data.

   data: The data buffer to send to the resource.

   Returns: A System.Byte array containing the body of the response from the resource.
  """
  pass
 def UploadDataAsync(self,address,*__args):
  """
  UploadDataAsync(self: WebClient,address: Uri,method: str,data: Array[Byte],userToken: object)

   Uploads a data buffer to a resource identified by a URI,using the specified method and 

    identifying token.

  

  

   address: The URI of the resource to receive the data.

   method: The HTTP method used to send the file to the resource. If null,the default is POST for http and 

    STOR for ftp.

  

   data: The data buffer to send to the resource.

   userToken: A user-defined object that is passed to the method invoked when the asynchronous operation 

    completes.

  

  UploadDataAsync(self: WebClient,address: Uri,method: str,data: Array[Byte])

   Uploads a data buffer to a resource identified by a URI,using the specified method. This method 

    does not block the calling thread.

  

  

   address: The URI of the resource to receive the data.

   method: The HTTP method used to send the file to the resource. If null,the default is POST for http and 

    STOR for ftp.

  

   data: The data buffer to send to the resource.

  UploadDataAsync(self: WebClient,address: Uri,data: Array[Byte])

   Uploads a data buffer to a resource identified by a URI,using the POST method. This method does 

    not block the calling thread.

  

  

   address: The URI of the resource to receive the data.

   data: The data buffer to send to the resource.
  """
  pass
 def UploadDataTaskAsync(self,address,*__args):
  """
  UploadDataTaskAsync(self: WebClient,address: str,method: str,data: Array[Byte]) -> Task[Array[Byte]]

  UploadDataTaskAsync(self: WebClient,address: Uri,method: str,data: Array[Byte]) -> Task[Array[Byte]]

  UploadDataTaskAsync(self: WebClient,address: str,data: Array[Byte]) -> Task[Array[Byte]]

  UploadDataTaskAsync(self: WebClient,address: Uri,data: Array[Byte]) -> Task[Array[Byte]]
  """
  pass
 def UploadFile(self,address,*__args):
  """
  UploadFile(self: WebClient,address: str,method: str,fileName: str) -> Array[Byte]

  

   Uploads the specified local file to the specified resource,using the specified method.

  

   address: The URI of the resource to receive the file.

   method: The HTTP method used to send the file to the resource. If null,the default is POST for http and 

    STOR for ftp.

  

   fileName: The file to send to the resource.

   Returns: A System.Byte array containing the body of the response from the resource.

  UploadFile(self: WebClient,address: Uri,method: str,fileName: str) -> Array[Byte]

  

   Uploads the specified local file to the specified resource,using the specified method.

  

   address: The URI of the resource to receive the file.

   method: The HTTP method used to send the file to the resource. If null,the default is POST for http and 

    STOR for ftp.

  

   fileName: The file to send to the resource.

   Returns: A System.Byte array containing the body of the response from the resource.

  UploadFile(self: WebClient,address: str,fileName: str) -> Array[Byte]

  

   Uploads the specified local file to a resource with the specified URI.

  

   address: The URI of the resource to receive the file. For example,ftp://localhost/samplefile.txt.

   fileName: The file to send to the resource. For example,"samplefile.txt".

   Returns: A System.Byte array containing the body of the response from the resource.

  UploadFile(self: WebClient,address: Uri,fileName: str) -> Array[Byte]

  

   Uploads the specified local file to a resource with the specified URI.

  

   address: The URI of the resource to receive the file. For example,ftp://localhost/samplefile.txt.

   fileName: The file to send to the resource. For example,"samplefile.txt".

   Returns: A System.Byte array containing the body of the response from the resource.
  """
  pass
 def UploadFileAsync(self,address,*__args):
  """
  UploadFileAsync(self: WebClient,address: Uri,method: str,fileName: str,userToken: object)

   Uploads the specified local file to the specified resource,using the POST method. This method 

    does not block the calling thread.

  

  

   address: The URI of the resource to receive the file. For HTTP resources,this URI must identify a 

    resource that can accept a request sent with the POST method,such as a script or ASP page.

  

   method: The HTTP method used to send the data to the resource. If null,the default is POST for http and 

    STOR for ftp.

  

   fileName: The file to send to the resource.

   userToken: A user-defined object that is passed to the method invoked when the asynchronous operation 

    completes.

  

  UploadFileAsync(self: WebClient,address: Uri,method: str,fileName: str)

   Uploads the specified local file to the specified resource,using the POST method. This method 

    does not block the calling thread.

  

  

   address: The URI of the resource to receive the file. For HTTP resources,this URI must identify a 

    resource that can accept a request sent with the POST method,such as a script or ASP page.

  

   method: The HTTP method used to send the data to the resource. If null,the default is POST for http and 

    STOR for ftp.

  

   fileName: The file to send to the resource.

  UploadFileAsync(self: WebClient,address: Uri,fileName: str)

   Uploads the specified local file to the specified resource,using the POST method. This method 

    does not block the calling thread.

  

  

   address: The URI of the resource to receive the file. For HTTP resources,this URI must identify a 

    resource that can accept a request sent with the POST method,such as a script or ASP page.

  

   fileName: The file to send to the resource.
  """
  pass
 def UploadFileTaskAsync(self,address,*__args):
  """
  UploadFileTaskAsync(self: WebClient,address: str,method: str,fileName: str) -> Task[Array[Byte]]

  UploadFileTaskAsync(self: WebClient,address: Uri,method: str,fileName: str) -> Task[Array[Byte]]

  UploadFileTaskAsync(self: WebClient,address: str,fileName: str) -> Task[Array[Byte]]

  UploadFileTaskAsync(self: WebClient,address: Uri,fileName: str) -> Task[Array[Byte]]
  """
  pass
 def UploadString(self,address,*__args):
  """
  UploadString(self: WebClient,address: str,method: str,data: str) -> str

  

   Uploads the specified string to the specified resource,using the specified method.

  

   address: The URI of the resource to receive the file. This URI must identify a resource that can accept a 

    request sent with the method method.

  

   method: The HTTP method used to send the string to the resource. If null,the default is POST for http 

    and STOR for ftp.

  

   data: The string to be uploaded.

   Returns: A System.String containing the response sent by the server.

  UploadString(self: WebClient,address: Uri,method: str,data: str) -> str

  

   Uploads the specified string to the specified resource,using the specified method.

  

   address: The URI of the resource to receive the file. This URI must identify a resource that can accept a 

    request sent with the method method.

  

   method: The HTTP method used to send the string to the resource. If null,the default is POST for http 

    and STOR for ftp.

  

   data: The string to be uploaded.

   Returns: A System.String containing the response sent by the server.

  UploadString(self: WebClient,address: str,data: str) -> str

  

   Uploads the specified string to the specified resource,using the POST method.

  

   address: The URI of the resource to receive the string. For Http resources,this URI must identify a 

    resource that can accept a request sent with the POST method,such as a script or ASP page.

  

   data: The string to be uploaded.

   Returns: A System.String containing the response sent by the server.

  UploadString(self: WebClient,address: Uri,data: str) -> str

  

   Uploads the specified string to the specified resource,using the POST method.

  

   address: The URI of the resource to receive the string. For Http resources,this URI must identify a 

    resource that can accept a request sent with the POST method,such as a script or ASP page.

  

   data: The string to be uploaded.

   Returns: A System.String containing the response sent by the server.
  """
  pass
 def UploadStringAsync(self,address,*__args):
  """
  UploadStringAsync(self: WebClient,address: Uri,method: str,data: str,userToken: object)

   Uploads the specified string to the specified resource. This method does not block the calling 

    thread.

  

  

   address: The URI of the resource to receive the file. For HTTP resources,this URI must identify a 

    resource that can accept a request sent with the POST method,such as a script or ASP page.

  

   method: The HTTP method used to send the file to the resource. If null,the default is POST for http and 

    STOR for ftp.

  

   data: The string to be uploaded.

   userToken: A user-defined object that is passed to the method invoked when the asynchronous operation 

    completes.

  

  UploadStringAsync(self: WebClient,address: Uri,method: str,data: str)

   Uploads the specified string to the specified resource. This method does not block the calling 

    thread.

  

  

   address: The URI of the resource to receive the file. For HTTP resources,this URI must identify a 

    resource that can accept a request sent with the POST method,such as a script or ASP page.

  

   method: The HTTP method used to send the file to the resource. If null,the default is POST for http and 

    STOR for ftp.

  

   data: The string to be uploaded.

  UploadStringAsync(self: WebClient,address: Uri,data: str)

   Uploads the specified string to the specified resource. This method does not block the calling 

    thread.

  

  

   address: The URI of the resource to receive the file. For HTTP resources,this URI must identify a 

    resource that can accept a request sent with the POST method,such as a script or ASP page.

  

   data: The string to be uploaded.
  """
  pass
 def UploadStringTaskAsync(self,address,*__args):
  """
  UploadStringTaskAsync(self: WebClient,address: str,method: str,data: str) -> Task[str]

  UploadStringTaskAsync(self: WebClient,address: Uri,method: str,data: str) -> Task[str]

  UploadStringTaskAsync(self: WebClient,address: str,data: str) -> Task[str]

  UploadStringTaskAsync(self: WebClient,address: Uri,data: str) -> Task[str]
  """
  pass
 def UploadValues(self,address,*__args):
  """
  UploadValues(self: WebClient,address: str,method: str,data: NameValueCollection) -> Array[Byte]

  

   Uploads the specified name/value collection to the resource identified by the specified URI,

    using the specified method.

  

  

   address: The URI of the resource to receive the collection.

   method: The HTTP method used to send the file to the resource. If null,the default is POST for http and 

    STOR for ftp.

  

   data: The System.Collections.Specialized.NameValueCollection to send to the resource.

   Returns: A System.Byte array containing the body of the response from the resource.

  UploadValues(self: WebClient,address: Uri,method: str,data: NameValueCollection) -> Array[Byte]

  

   Uploads the specified name/value collection to the resource identified by the specified URI,

    using the specified method.

  

  

   address: The URI of the resource to receive the collection.

   method: The HTTP method used to send the file to the resource. If null,the default is POST for http and 

    STOR for ftp.

  

   data: The System.Collections.Specialized.NameValueCollection to send to the resource.

   Returns: A System.Byte array containing the body of the response from the resource.

  UploadValues(self: WebClient,address: str,data: NameValueCollection) -> Array[Byte]

  

   Uploads the specified name/value collection to the resource identified by the specified URI.

  

   address: The URI of the resource to receive the collection.

   data: The System.Collections.Specialized.NameValueCollection to send to the resource.

   Returns: A System.Byte array containing the body of the response from the resource.

  UploadValues(self: WebClient,address: Uri,data: NameValueCollection) -> Array[Byte]

  

   Uploads the specified name/value collection to the resource identified by the specified URI.

  

   address: The URI of the resource to receive the collection.

   data: The System.Collections.Specialized.NameValueCollection to send to the resource.

   Returns: A System.Byte array containing the body of the response from the resource.
  """
  pass
 def UploadValuesAsync(self,address,*__args):
  """
  UploadValuesAsync(self: WebClient,address: Uri,method: str,data: NameValueCollection,userToken: object)

   Uploads the data in the specified name/value collection to the resource identified by the 

    specified URI,using the specified method. This method does not block the calling thread,and 

    allows the caller to pass an object to the method that is invoked when the operation completes.

  

  

   address: The URI of the resource to receive the collection. This URI must identify a resource that can 

    accept a request sent with the method method.

  

   method: The HTTP method used to send the string to the resource. If null,the default is POST for http 

    and STOR for ftp.

  

   data: The System.Collections.Specialized.NameValueCollection to send to the resource.

   userToken: A user-defined object that is passed to the method invoked when the asynchronous operation 

    completes.

  

  UploadValuesAsync(self: WebClient,address: Uri,method: str,data: NameValueCollection)

   Uploads the data in the specified name/value collection to the resource identified by the 

    specified URI,using the specified method. This method does not block the calling thread.

  

  

   address: The URI of the resource to receive the collection. This URI must identify a resource that can 

    accept a request sent with the method method.

  

   method: The method used to send the string to the resource. If null,the default is POST for http and 

    STOR for ftp.

  

   data: The System.Collections.Specialized.NameValueCollection to send to the resource.

  UploadValuesAsync(self: WebClient,address: Uri,data: NameValueCollection)

   Uploads the data in the specified name/value collection to the resource identified by the 

    specified URI. This method does not block the calling thread.

  

  

   address: The URI of the resource to receive the collection. This URI must identify a resource that can 

    accept a request sent with the default method. See remarks.

  

   data: The System.Collections.Specialized.NameValueCollection to send to the resource.
  """
  pass
 def UploadValuesTaskAsync(self,address,*__args):
  """
  UploadValuesTaskAsync(self: WebClient,address: Uri,data: NameValueCollection) -> Task[Array[Byte]]

  UploadValuesTaskAsync(self: WebClient,address: Uri,method: str,data: NameValueCollection) -> Task[Array[Byte]]

  UploadValuesTaskAsync(self: WebClient,address: str,data: NameValueCollection) -> Task[Array[Byte]]

  UploadValuesTaskAsync(self: WebClient,address: str,method: str,data: NameValueCollection) -> Task[Array[Byte]]
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 AllowReadStreamBuffering=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: AllowReadStreamBuffering(self: WebClient) -> bool



Set: AllowReadStreamBuffering(self: WebClient)=value

"""

 AllowWriteStreamBuffering=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: AllowWriteStreamBuffering(self: WebClient) -> bool



Set: AllowWriteStreamBuffering(self: WebClient)=value

"""

 BaseAddress=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the base URI for requests made by a System.Net.WebClient.



Get: BaseAddress(self: WebClient) -> str



Set: BaseAddress(self: WebClient)=value

"""

 CachePolicy=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the application's cache policy for any resources obtained by this WebClient instance using System.Net.WebRequest objects.



Get: CachePolicy(self: WebClient) -> RequestCachePolicy



Set: CachePolicy(self: WebClient)=value

"""

 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 Credentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the network credentials that are sent to the host and used to authenticate the request.



Get: Credentials(self: WebClient) -> ICredentials



Set: Credentials(self: WebClient)=value

"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 Encoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets and sets the System.Text.Encoding used to upload and download strings.



Get: Encoding(self: WebClient) -> Encoding



Set: Encoding(self: WebClient)=value

"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 Headers=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a collection of header name/value pairs associated with the request.



Get: Headers(self: WebClient) -> WebHeaderCollection



Set: Headers(self: WebClient)=value

"""

 IsBusy=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets whether a Web request is in progress.



Get: IsBusy(self: WebClient) -> bool



"""

 Proxy=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the proxy used by this System.Net.WebClient object.



Get: Proxy(self: WebClient) -> IWebProxy



Set: Proxy(self: WebClient)=value

"""

 QueryString=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a collection of query name/value pairs associated with the request.



Get: QueryString(self: WebClient) -> NameValueCollection



Set: QueryString(self: WebClient)=value

"""

 ResponseHeaders=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of header name/value pairs associated with the response.



Get: ResponseHeaders(self: WebClient) -> WebHeaderCollection



"""

 UseDefaultCredentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a System.Boolean value that controls whether the System.Net.CredentialCache.DefaultCredentials are sent with requests.



Get: UseDefaultCredentials(self: WebClient) -> bool



Set: UseDefaultCredentials(self: WebClient)=value

"""


 DownloadDataCompleted=None
 DownloadFileCompleted=None
 DownloadProgressChanged=None
 DownloadStringCompleted=None
 OpenReadCompleted=None
 OpenWriteCompleted=None
 UploadDataCompleted=None
 UploadFileCompleted=None
 UploadProgressChanged=None
 UploadStringCompleted=None
 UploadValuesCompleted=None
 WriteStreamClosed=None




class ComRegisterFunctionAttribute(Attribute,_Attribute):
 """
 Specifies the method to call when you register an assembly for use from COM; this enables the execution of user-written code during the registration process.

 

 ComRegisterFunctionAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class GenericUriParser(UriParser):
 """
 A customizable parser for a hierarchical URI.

 

 GenericUriParser(options: GenericUriParserOptions)
 """
 @staticmethod
 def __new__(self,options):
  """ __new__(cls: type,options: GenericUriParserOptions) """
  pass



class IBindableComponent(IComponent,IDisposable):
 """ Enables a non-control component to emulate the data-binding behavior of a Windows Forms control. """
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 BindingContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the collection of currency managers for the System.Windows.Forms.IBindableComponent.



Get: BindingContext(self: IBindableComponent) -> BindingContext



Set: BindingContext(self: IBindableComponent)=value

"""

 DataBindings=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of data-binding objects for this System.Windows.Forms.IBindableComponent.



Get: DataBindings(self: IBindableComponent) -> ControlBindingsCollection



"""





"""Base module for pyRevit config parsing."""
import json
import codecs
from pyrevit.compat import configparser

from pyrevit import PyRevitException, PyRevitIOError
from pyrevit import coreutils

#pylint: disable=W0703,C0302
KEY_VALUE_TRUE = "True"
KEY_VALUE_FALSE = "False"


class PyRevitConfigSectionParser(object):
    """Config section parser object. Handle section options."""
    def __init__(self, config_parser, section_name):
        self._parser = config_parser
        self._section_name = section_name

    def __iter__(self):
        return iter(self._parser.options(self._section_name))

    def __str__(self):
        return self._section_name

    def __repr__(self):
        return '<PyRevitConfigSectionParser object '    \
               'at 0x{0:016x} '                         \
               'config section \'{1}\'>'                \
               .format(id(self), self._section_name)

    def __getattr__(self, param_name):
        try:
            value = self._parser.get(self._section_name, param_name)
            try:
                try:
                    return json.loads(value)  #pylint: disable=W0123
                except Exception:
                    # try fix legacy formats
                    # cleanup python style true, false values
                    if value == KEY_VALUE_TRUE:
                        value = json.dumps(True)
                    elif value == KEY_VALUE_FALSE:
                        value = json.dumps(False)
                    # cleanup string representations
                    value = value.replace('\'', '"').encode('string-escape')
                    # try parsing again
                    try:
                        return json.loads(value)  #pylint: disable=W0123
                    except Exception:
                        # if failed again then the value is a string
                        # but is not encapsulated in quotes
                        # e.g. option = C:\Users\Desktop
                        value = value.strip()
                        if (not value.startswith('(')
                                and not value.startswith('[')
                                and not value.startswith('{')):
                            value = "\"%s\"" % value
                        return json.loads(value)  #pylint: disable=W0123
            except Exception:
                return value
        except (configparser.NoOptionError, configparser.NoSectionError):
            raise AttributeError('Parameter does not exist in config file: {}'
                                 .format(param_name))

    def __setattr__(self, param_name, value):
        # check agaist used attribute names
        if param_name in ['_parser', '_section_name']:
            super(PyRevitConfigSectionParser, self).__setattr__(param_name,
                                                                value)
        else:
            # if not used by this object, then set a config section
            try:
                return self._parser.set(self._section_name,
                                        param_name,
                                        json.dumps(value,
                                                   separators=(',', ':'),
                                                   ensure_ascii=False))
            except Exception as set_err:
                raise PyRevitException('Error setting parameter value. '
                                       '| {}'.format(set_err))

    @property
    def header(self):
        """Section header."""
        return self._section_name

    @property
    def subheader(self):
        """Section sub-header e.g. Section.SubSection."""
        return coreutils.get_canonical_parts(self.header)[-1]

    def has_option(self, option_name):
        """Check if section contains given option."""
        return self._parser.has_option(self._section_name, option_name)

    def get_option(self, op_name, default_value=None):
        """Get option value or return default."""
        try:
            return self.__getattr__(op_name)
        except Exception as opt_get_err:
            if default_value is not None:
                return default_value
            else:
                raise opt_get_err

    def set_option(self, op_name, value):
        """Set value of given option."""
        self.__setattr__(op_name, value)

    def remove_option(self, option_name):
        """Remove given option from section."""
        return self._parser.remove_option(self._section_name, option_name)

    def has_subsection(self, section_name):
        """Check if section has any subsections."""
        return True if self.get_subsection(section_name) else False

    def add_subsection(self, section_name):
        """Add subsection to section."""
        return self._parser.add_section(
            coreutils.make_canonical_name(self._section_name, section_name)
        )

    def get_subsections(self):
        """Get all subsections."""
        subsections = []
        for section_name in self._parser.sections():
            if section_name.startswith(self._section_name + '.'):
                subsec = PyRevitConfigSectionParser(self._parser, section_name)
                subsections.append(subsec)
        return subsections

    def get_subsection(self, section_name):
        """Get subsection with given name."""
        for subsection in self.get_subsections():
            if subsection.subheader == section_name:
                return subsection


class PyRevitConfigParser(object):
    """Config parser object. Handle config sections and io."""
    def __init__(self, cfg_file_path=None):
        self._cfg_file_path = cfg_file_path
        self._parser = configparser.ConfigParser()
        if self._cfg_file_path:
            try:
                with codecs.open(self._cfg_file_path, 'r', 'utf-8') as cfg_file:
                    try:
                        self._parser.readfp(cfg_file)
                    except AttributeError:
                        self._parser.read_file(cfg_file)
            except (OSError, IOError):
                raise PyRevitIOError()
            except Exception as read_err:
                raise PyRevitException(read_err)

    def __iter__(self):
        return iter([self.get_section(x) for x in self._parser.sections()])

    def __getattr__(self, section_name):
        if self._parser.has_section(section_name):
            # build a section parser object and return
            return PyRevitConfigSectionParser(self._parser, section_name)
        else:
            raise AttributeError(
                'Section \"{}\" does not exist in config file.'
                .format(section_name))

    def get_config_file_hash(self):
        """Get calculated unique hash for this config.

        Returns:
            (str): hash of the config.
        """
        with codecs.open(self._cfg_file_path, 'r', 'utf-8') as cfg_file:
            cfg_hash = coreutils.get_str_hash(cfg_file.read())

        return cfg_hash

    def has_section(self, section_name):
        """Check if config contains given section."""
        try:
            self.get_section(section_name)
            return True
        except Exception:
            return False

    def add_section(self, section_name):
        """Add section with given name to config."""
        self._parser.add_section(section_name)
        return PyRevitConfigSectionParser(self._parser, section_name)

    def get_section(self, section_name):
        """Get section with given name.

        Raises:
            AttributeError: if section is missing
        """
        # check is section with full name is available
        if self._parser.has_section(section_name):
            return PyRevitConfigSectionParser(self._parser, section_name)

        # if not try to match with section_name.subsection
        # if there is a section_name.subsection defined, that should be
        # the sign that the section exists
        # section obj then supports getting all subsections
        for cfg_section_name in self._parser.sections():
            master_section = coreutils.get_canonical_parts(cfg_section_name)[0]
            if section_name == master_section:
                return PyRevitConfigSectionParser(self._parser,
                                                  master_section)

        # if no match happened then raise exception
        raise AttributeError('Section does not exist in config file.')

    def remove_section(self, section_name):
        """Remove section from config."""
        cfg_section = self.get_section(section_name)
        for cfg_subsection in cfg_section.get_subsections():
            self._parser.remove_section(cfg_subsection.header)
        self._parser.remove_section(cfg_section.header)

    def reload(self, cfg_file_path=None):
        """Reload config from original or given file."""
        try:
            with codecs.open(cfg_file_path \
                    or self._cfg_file_path, 'r', 'utf-8') as cfg_file:
                try:
                    self._parser.readfp(cfg_file)
                except AttributeError:
                    self._parser.read_file(cfg_file)
        except (OSError, IOError):
            raise PyRevitIOError()

    def save(self, cfg_file_path=None):
        """Save config to original or given file."""
        try:
            with codecs.open(cfg_file_path \
                    or self._cfg_file_path, 'w', 'utf-8') as cfg_file:
                self._parser.write(cfg_file)
        except (OSError, IOError):
            raise PyRevitIOError()



class Int64(object,IComparable,IFormattable,IConvertible,IComparable[Int64],IEquatable[Int64]):
 """ Represents a 64-bit signed integer. """
 def bit_length(self,*args):
  """ bit_length(value: Int64) -> int """
  pass
 def CompareTo(self,value):
  """
  CompareTo(self: Int64,value: Int64) -> int

  

   Compares this instance to a specified 64-bit signed integer and returns an indication of their 

    relative values.

  

  

   value: An integer to compare.

   Returns: A signed number indicating the relative values of this instance and value.Return Value 

    Description Less than zero This instance is less than value. Zero This instance is equal to 

    value. Greater than zero This instance is greater than value.

  

  CompareTo(self: Int64,value: object) -> int

  

   Compares this instance to a specified object and returns an indication of their relative values.

  

   value: An object to compare,or null.

   Returns: A signed number indicating the relative values of this instance and value.Return Value 

    Description Less than zero This instance is less than value. Zero This instance is equal to 

    value. Greater than zero This instance is greater than value.-or- value is null.
  """
  pass
 def conjugate(self,*args):
  """ conjugate(x: Int64) -> Int64 """
  pass
 def Equals(self,obj):
  """
  Equals(self: Int64,obj: Int64) -> bool

  

   Returns a value indicating whether this instance is equal to a specified System.Int64 value.

  

   obj: An System.Int64 value to compare to this instance.

   Returns: true if obj has the same value as this instance; otherwise,false.

  Equals(self: Int64,obj: object) -> bool

  

   Returns a value indicating whether this instance is equal to a specified object.

  

   obj: An object to compare with this instance.

   Returns: true if obj is an instance of an System.Int64 and equals the value of this instance; otherwise,

    false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: Int64) -> int

  

   Returns the hash code for this instance.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 def GetTypeCode(self):
  """
  GetTypeCode(self: Int64) -> TypeCode

  

   Returns the System.TypeCode for value type System.Int64.

   Returns: The enumerated constant,System.TypeCode.Int64.
  """
  pass
 @staticmethod
 def Parse(s,*__args):
  """
  Parse(s: str,provider: IFormatProvider) -> Int64

  

   Converts the string representation of a number in a specified culture-specific format to its 

    64-bit signed integer equivalent.

  

  

   s: A string containing a number to convert.

   provider: An object that supplies culture-specific formatting information about s.

   Returns: A 64-bit signed integer equivalent to the number specified in s.

  Parse(s: str,style: NumberStyles,provider: IFormatProvider) -> Int64

  

   Converts the string representation of a number in a specified style and culture-specific format 

    to its 64-bit signed integer equivalent.

  

  

   s: A string containing a number to convert.

   style: A bitwise combination of enumeration values that indicates the style elements that can be 

    present in s. A typical value to specify is System.Globalization.NumberStyles.Integer.

  

   provider: An System.IFormatProvider that supplies culture-specific formatting information about s.

   Returns: A 64-bit signed integer equivalent to the number specified in s.

  Parse(s: str) -> Int64

  

   Converts the string representation of a number to its 64-bit signed integer equivalent.

  

   s: A string containing a number to convert.

   Returns: A 64-bit signed integer equivalent to the number contained in s.

  Parse(s: str,style: NumberStyles) -> Int64

  

   Converts the string representation of a number in a specified style to its 64-bit signed integer 

    equivalent.

  

  

   s: A string containing a number to convert.

   style: A bitwise combination of System.Globalization.NumberStyles values that indicates the permitted 

    format of s. A typical value to specify is System.Globalization.NumberStyles.Integer.

  

   Returns: A 64-bit signed integer equivalent to the number specified in s.
  """
  pass
 def ToString(self,*__args):
  """
  ToString(self: Int64,format: str) -> str

  

   Converts the numeric value of this instance to its equivalent string representation,using the 

    specified format.

  

  

   format: A numeric format string.

   Returns: The string representation of the value of this instance as specified by format.

  ToString(self: Int64,format: str,provider: IFormatProvider) -> str

  

   Converts the numeric value of this instance to its equivalent string representation using the 

    specified format and culture-specific format information.

  

  

   format: A numeric format string.

   provider: An object that supplies culture-specific formatting information about this instance.

   Returns: The string representation of the value of this instance as specified by format and provider.

  ToString(self: Int64) -> str

  

   Converts the numeric value of this instance to its equivalent string representation.

   Returns: The string representation of the value of this instance,consisting of a minus sign if the value 

    is negative,and a sequence of digits ranging from 0 to 9 with no leading zeroes.

  

  ToString(self: Int64,provider: IFormatProvider) -> str

  

   Converts the numeric value of this instance to its equivalent string representation using the 

    specified culture-specific format information.

  

  

   provider: An System.IFormatProvider that supplies culture-specific formatting information.

   Returns: The string representation of the value of this instance as specified by provider.
  """
  pass
 @staticmethod
 def TryParse(s,*__args):
  """
  TryParse(s: str,style: NumberStyles,provider: IFormatProvider) -> (bool,Int64)

  

   Converts the string representation of a number in a specified style and culture-specific format 

    to its 64-bit signed integer equivalent. A return value indicates whether the conversion 

    succeeded or failed.

  

  

   s: A string containing a number to convert. The string is interpreted using the style specified by 

    style.

  

   style: A bitwise combination of enumeration values that indicates the style elements that can be 

    present in s. A typical value to specify is System.Globalization.NumberStyles.Integer.

  

   provider: An object that supplies culture-specific formatting information about s.

   Returns: true if s was converted successfully; otherwise,false.

  TryParse(s: str) -> (bool,Int64)

  

   Converts the string representation of a number to its 64-bit signed integer equivalent. A return 

    value indicates whether the conversion succeeded or failed.

  

  

   s: A string containing a number to convert.

   Returns: true if s was converted successfully; otherwise,false.
  """
  pass
 def __abs__(self,*args):
  """ x.__abs__() <==> abs(x) """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __and__(self,*args):
  """ __and__(x: Int64,y: Int64) -> Int64 """
  pass
 def __cmp__(self,*args):
  """ x.__cmp__(y) <==> cmp(x,y) """
  pass
 def __div__(self,*args):
  """ x.__div__(y) <==> x/y """
  pass
 def __float__(self,*args):
  """ __float__(x: Int64) -> float """
  pass
 def __floordiv__(self,*args):
  """ x.__floordiv__(y) <==> x//y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __hash__(self,*args):
  """ x.__hash__() <==> hash(x) """
  pass
 def __hex__(self,*args):
  """ __hex__(value: Int64) -> str """
  pass
 def __index__(self,*args):
  """ __index__(x: Int64) -> long """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __int__(self,*args):
  """ __int__(x: Int64) -> int """
  pass
 def __invert__(self,*args):
  """ __invert__(x: Int64) -> Int64 """
  pass
 def __lshift__(self,*args):
  """ x.__rshift__(y) <==> x<<y """
  pass
 def __mod__(self,*args):
  """ x.__mod__(y) <==> x%y """
  pass
 def __mul__(self,*args):
  """ x.__mul__(y) <==> x*y """
  pass
 def __neg__(self,*args):
  """ x.__neg__() <==> -x """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """
  __new__(cls: type,value: object) -> object

  __new__(cls: type) -> object
  """
  pass
 def __nonzero__(self,*args):
  """ __nonzero__(x: Int64) -> bool """
  pass
 def __or__(self,*args):
  """ __or__(x: Int64,y: Int64) -> Int64 """
  pass
 def __pos__(self,*args):
  """ __pos__(x: Int64) -> Int64 """
  pass
 def __pow__(self,*args):
  """ x.__pow__(y[,z]) <==> pow(x,y[,z]) """
  pass
 def __radd__(self,*args):
  """ __radd__(x: Int64,y: Int64) -> object """
  pass
 def __rand__(self,*args):
  """ __rand__(x: Int64,y: Int64) -> Int64 """
  pass
 def __rdiv__(self,*args):
  """ __rdiv__(x: Int64,y: Int64) -> object """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(x: Int64) -> str """
  pass
 def __rfloordiv__(self,*args):
  """ __rfloordiv__(x: Int64,y: Int64) -> object """
  pass
 def __rmod__(self,*args):
  """ __rmod__(x: Int64,y: Int64) -> Int64 """
  pass
 def __rmul__(self,*args):
  """ __rmul__(x: Int64,y: Int64) -> object """
  pass
 def __ror__(self,*args):
  """ __ror__(x: Int64,y: Int64) -> Int64 """
  pass
 def __rpow__(self,*args):
  """ __rpow__(x: Int64,y: Int64) -> object """
  pass
 def __rshift__(self,*args):
  """ x.__rshift__(y) <==> x>>y """
  pass
 def __rsub__(self,*args):
  """ __rsub__(x: Int64,y: Int64) -> object """
  pass
 def __rtruediv__(self,*args):
  """ __rtruediv__(x: Int64,y: Int64) -> float """
  pass
 def __rxor__(self,*args):
  """ __rxor__(x: Int64,y: Int64) -> Int64 """
  pass
 def __str__(self,*args):
  pass
 def __sub__(self,*args):
  """ x.__sub__(y) <==> x-y """
  pass
 def __truediv__(self,*args):
  """ x.__truediv__(y) <==> x/y """
  pass
 def __trunc__(self,*args):
  """ __trunc__(x: Int64) -> Int64 """
  pass
 def __xor__(self,*args):
  """ __xor__(x: Int64,y: Int64) -> Int64 """
  pass
 denominator=None
 imag=None
 MaxValue=None
 MinValue=None
 numerator=None
 real=None




class GridItemCollection(object,ICollection,IEnumerable):
 """ Contains a collection of System.Windows.Forms.GridItem objects. """
 def GetEnumerator(self):
  """
  GetEnumerator(self: GridItemCollection) -> IEnumerator

  

   Returns an enumeration of all the grid items in the collection.

   Returns: An System.Collections.IEnumerator for the System.Windows.Forms.GridItemCollection.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of grid items in the collection.



Get: Count(self: GridItemCollection) -> int



"""


 Empty=None




# encoding: utf-8
# module System.Drawing calls itself Drawing
# from System.Drawing,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b03f5f7f11d50a3a
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from __init___parts.Image import Image
from __init___parts.Bitmap import Bitmap
from __init___parts.BitmapSuffixInSameAssemblyAttribute import BitmapSuffixInSameAssemblyAttribute
from __init___parts.BitmapSuffixInSatelliteAssemblyAttribute import BitmapSuffixInSatelliteAssemblyAttribute
from __init___parts.Brush import Brush
from __init___parts.Brushes import Brushes
from __init___parts.BufferedGraphics import BufferedGraphics
from __init___parts.BufferedGraphicsContext import BufferedGraphicsContext
from __init___parts.BufferedGraphicsManager import BufferedGraphicsManager
from __init___parts.CharacterRange import CharacterRange
from __init___parts.Color import Color
from __init___parts.ColorConverter import ColorConverter
from __init___parts.ColorTranslator import ColorTranslator
from __init___parts.ContentAlignment import ContentAlignment
from __init___parts.CopyPixelOperation import CopyPixelOperation
from __init___parts.Font import Font
from __init___parts.FontConverter import FontConverter
from __init___parts.FontFamily import FontFamily
from __init___parts.FontStyle import FontStyle
from __init___parts.Graphics import Graphics
from __init___parts.GraphicsUnit import GraphicsUnit
from __init___parts.Icon import Icon
from __init___parts.IconConverter import IconConverter
from __init___parts.IDeviceContext import IDeviceContext
from __init___parts.ImageAnimator import ImageAnimator
from __init___parts.ImageConverter import ImageConverter
from __init___parts.ImageFormatConverter import ImageFormatConverter
from __init___parts.KnownColor import KnownColor
from __init___parts.Pen import Pen
from __init___parts.Pens import Pens
from __init___parts.Point import Point
from __init___parts.PointConverter import PointConverter
from __init___parts.PointF import PointF
from __init___parts.Rectangle import Rectangle
from __init___parts.RectangleConverter import RectangleConverter
from __init___parts.RectangleF import RectangleF
from __init___parts.Region import Region
from __init___parts.RotateFlipType import RotateFlipType
from __init___parts.Size import Size
from __init___parts.SizeConverter import SizeConverter
from __init___parts.SizeF import SizeF
from __init___parts.SizeFConverter import SizeFConverter
from __init___parts.SolidBrush import SolidBrush
from __init___parts.StringAlignment import StringAlignment
from __init___parts.StringDigitSubstitute import StringDigitSubstitute
from __init___parts.StringFormat import StringFormat
from __init___parts.StringFormatFlags import StringFormatFlags
from __init___parts.StringTrimming import StringTrimming
from __init___parts.StringUnit import StringUnit
from __init___parts.SystemBrushes import SystemBrushes
from __init___parts.SystemColors import SystemColors
from __init___parts.SystemFonts import SystemFonts
from __init___parts.SystemIcons import SystemIcons
from __init___parts.SystemPens import SystemPens
from __init___parts.TextureBrush import TextureBrush
from __init___parts.ToolboxBitmapAttribute import ToolboxBitmapAttribute



# -*- coding: UTF-8 -*-

""" This module contains functions to generate HTML cards for use in pyRevit output. """


def card_start_style(limit, value, alt):
    """
    Generates an HTML div element with a specific background color based on the ratio of value to limit.

    Args:
        limit (float): The limit value used to calculate the ratio.
        value (float): The current value to be compared against the limit.
        alt (str): The alt text for the div element.

    Returns:
        str: An HTML div element as a string with inline styles and the specified background color.
    The background color is determined by the following rules:
        - 'Grey' if value is 0 or if an exception occurs during ratio calculation.
        - 'Green' if 0 <= ratio < 0.5.
        - 'Orange' if 0.5 <= ratio <= 1.
        - 'Red' if ratio > 1.
    """
    try:
        ratio = float(value) / float(limit)
    except ZeroDivisionError:
        ratio = 0
    color = "#d0d3d4"
    if value != 0:
        if ratio < 0.5:
            color = "#D0E6A5"  # green
        elif ratio <= 1:
            color = "#FFDD94"  # orange
        else:
            color = "#FA897B"  # red
    try:
        card_start = '<div style="display: inline-block; width: 100px; height: 40px; background: {}; font-family: sans-serif; font-size: 0.85rem; padding: 5px; text-align: center; border-radius: 8px; margin: 5px; box-shadow: 0 6px 6px 0 rgba(0, 0, 0, 0.2); vertical-align: top;" alt="{}">'.format(
            color, alt
        )
    except Exception as e:
        print(e)
    return card_start


def card_builder(limit, value, description):
    """
    Builds an HTML card with the given limit, value, and description.

    Args:
        limit (int): The limit value to be displayed in the card.
        value (int or str): The main value to be displayed in the card.
        description (str): A description to be displayed in the card.

    Returns:
        str: A string containing the HTML representation of the card.
    """

    alt = "{} {} (limit = {})".format(str(value), str(description), str(limit))
    card_end = '<b>{}</b><br /><a style="font-size: 0.70rem">{}</a></div>'.format(
        value, description
    )
    return card_start_style(limit, value, alt) + card_end


def create_frame(title, *cards):
    """
    Creates an HTML div frame containing multiple cards with a rounded border and a title on the top left corner.

    return card_start_style(limit, value, alt) + card_end
        cards (str): Multiple strings representing HTML card elements.

    Returns:
        str: A string containing the HTML representation of the div frame.

    """
    # Add vertical-align: top to the frame and adjust title position
    frame_start = '<div style="display: inline-block; vertical-align: top; border: 1px solid #ccc; border-radius: 10px; padding: 5px; margin: 10px 5px 10px 5px; position: relative;">'
    title_html = '<div style="position: absolute; top: -12px; left: 10px; background: white; padding: 0 5px; font-weight: bold;">{}</div>'.format(
        title
    )
    cards_html = "".join(cards)
    frame_end = "</div>"
    return frame_start + title_html + cards_html + frame_end



class DateRangeEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.MonthCalendar.DateChanged or System.Windows.Forms.MonthCalendar.DateSelected events of the System.Windows.Forms.MonthCalendar control.

 

 DateRangeEventArgs(start: DateTime,end: DateTime)
 """
 @staticmethod
 def __new__(self,start,end):
  """ __new__(cls: type,start: DateTime,end: DateTime) """
  pass
 End=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the last date/time value in the range that the user has selected.



Get: End(self: DateRangeEventArgs) -> DateTime



"""

 Start=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the first date/time value in the range that the user has selected.



Get: Start(self: DateRangeEventArgs) -> DateTime



"""





from typing import Tuple, Set, Iterable, List


class JournalingAttribute:
    def __init__(self, mode: JournalingMode): ...
    @property
    def Mode(self) -> JournalingMode: ...


class RegenerationAttribute:
    def __init__(self, option: RegenerationOption): ...
    @property
    def Option(self) -> RegenerationOption: ...


class TransactionAttribute:
    def __init__(self, mode: TransactionMode): ...
    @property
    def Mode(self) -> TransactionMode: ...


class JournalingMode:
    UsingCommandData = 0
    NoCommandData = 1


class RegenerationOption:
    Manual = 0


class TransactionMode:
    Manual = 1
    ReadOnly = 2



class ErrorIconAlignment(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies constants indicating the locations that an error icon can appear in relation to the control with an error.

 

 enum ErrorIconAlignment,values: BottomLeft (4),BottomRight (5),MiddleLeft (2),MiddleRight (3),TopLeft (0),TopRight (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 BottomLeft=None
 BottomRight=None
 MiddleLeft=None
 MiddleRight=None
 TopLeft=None
 TopRight=None
 value__=None




class ReadOnlyAttribute(Attribute,_Attribute):
 """
 Specifies whether the property this attribute is bound to is read-only or read/write. This class cannot be inherited

 

 ReadOnlyAttribute(isReadOnly: bool)
 """
 def Equals(self,value):
  """
  Equals(self: ReadOnlyAttribute,value: object) -> bool

  

   Indicates whether this instance and a specified object are equal.

  

   value: Another object to compare to.

   Returns: true if value is equal to this instance; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: ReadOnlyAttribute) -> int

  

   Returns the hash code for this instance.

   Returns: A hash code for the current System.ComponentModel.ReadOnlyAttribute.
  """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: ReadOnlyAttribute) -> bool

  

   Determines if this attribute is the default.

   Returns: true if the attribute is the default value for this attribute class; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,isReadOnly):
  """ __new__(cls: type,isReadOnly: bool) """
  pass
 def __ne__(self,*args):
  pass
 IsReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the property this attribute is bound to is read-only.



Get: IsReadOnly(self: ReadOnlyAttribute) -> bool



"""


 Default=None
 No=None
 Yes=None




class PerformanceCounterCategory(object):
 """
 Represents a performance object,which defines a category of performance counters.

 

 PerformanceCounterCategory()

 PerformanceCounterCategory(categoryName: str)

 PerformanceCounterCategory(categoryName: str,machineName: str)
 """
 def CounterExists(self,counterName,categoryName=None,machineName=None):
  """
  CounterExists(counterName: str,categoryName: str,machineName: str) -> bool

  

   Determines whether the specified counter is registered to the specified category on a remote 

    computer.

  

  

   counterName: The name of the performance counter to look for.

   categoryName: The name of the performance counter category,or performance object,with which the specified 

    performance counter is associated.

  

   machineName: The name of the computer on which the performance counter category and its associated counters 

    exist.

  

   Returns: true,if the counter is registered to the specified category on the specified computer; 

    otherwise,false.

  

  CounterExists(counterName: str,categoryName: str) -> bool

  

   Determines whether the specified counter is registered to the specified category on the local 

    computer.

  

  

   counterName: The name of the performance counter to look for.

   categoryName: The name of the performance counter category,or performance object,with which the specified 

    performance counter is associated.

  

   Returns: true,if the counter is registered to the specified category on the local computer; otherwise,

    false.

  

  CounterExists(self: PerformanceCounterCategory,counterName: str) -> bool

  

   Determines whether the specified counter is registered to this category,which is indicated by 

    the System.Diagnostics.PerformanceCounterCategory.CategoryName and 

    System.Diagnostics.PerformanceCounterCategory.MachineName properties.

  

  

   counterName: The name of the performance counter to look for.

   Returns: true if the counter is registered to the category that is specified by the 

    System.Diagnostics.PerformanceCounterCategory.CategoryName and 

    System.Diagnostics.PerformanceCounterCategory.MachineName properties; otherwise,false.
  """
  pass
 @staticmethod
 def Create(categoryName,categoryHelp,*__args):
  """
  Create(categoryName: str,categoryHelp: str,counterData: CounterCreationDataCollection) -> PerformanceCounterCategory

  

   Registers the custom performance counter category containing the specified counters on the local 

    computer.

  

  

   categoryName: The name of the custom performance counter category to create and register with the system.

   categoryHelp: A description of the custom category.

   counterData: A System.Diagnostics.CounterCreationDataCollection that specifies the counters to create as part 

    of the new category.

  

   Returns: A System.Diagnostics.PerformanceCounterCategory that is associated with the new custom category,

    or performance object.

  

  Create(categoryName: str,categoryHelp: str,categoryType: PerformanceCounterCategoryType,counterData: CounterCreationDataCollection) -> PerformanceCounterCategory

  

   Registers the custom performance counter category containing the specified counters on the local 

    computer.

  

  

   categoryName: The name of the custom performance counter category to create and register with the system.

   categoryHelp: A description of the custom category.

   categoryType: One of the System.Diagnostics.PerformanceCounterCategoryType  values.

   counterData: A System.Diagnostics.CounterCreationDataCollection that specifies the counters to create as part 

    of the new category.

  

   Returns: A System.Diagnostics.PerformanceCounterCategory that is associated with the new custom category,

    or performance object.

  

  Create(categoryName: str,categoryHelp: str,counterName: str,counterHelp: str) -> PerformanceCounterCategory

  

   Registers a custom performance counter category containing a single counter of type 

    NumberOfItems32 on the local computer.

  

  

   categoryName: The name of the custom performance counter category to create and register with the system.

   categoryHelp: A description of the custom category.

   counterName: The name of a new counter,of type NumberOfItems32,to create as part of the new category.

   counterHelp: A description of the counter that is associated with the new custom category.

   Returns: A System.Diagnostics.PerformanceCounterCategory that is associated with the new system category,

    or performance object.

  

  Create(categoryName: str,categoryHelp: str,categoryType: PerformanceCounterCategoryType,counterName: str,counterHelp: str) -> PerformanceCounterCategory

  

   Registers the custom performance counter category containing a single counter of type 

    System.Diagnostics.PerformanceCounterType.NumberOfItems32 on the local computer.

  

  

   categoryName: The name of the custom performance counter category to create and register with the system.

   categoryHelp: A description of the custom category.

   categoryType: One of the System.Diagnostics.PerformanceCounterCategoryType  values specifying whether the 

    category is System.Diagnostics.PerformanceCounterCategoryType.MultiInstance,

    System.Diagnostics.PerformanceCounterCategoryType.SingleInstance,or 

    System.Diagnostics.PerformanceCounterCategoryType.Unknown.

  

   counterName: The name of a new counter to create as part of the new category.

   counterHelp: A description of the counter that is associated with the new custom category.

   Returns: A System.Diagnostics.PerformanceCounterCategory that is associated with the new system category,

    or performance object.
  """
  pass
 @staticmethod
 def Delete(categoryName):
  """
  Delete(categoryName: str)

   Removes the category and its associated counters from the local computer.

  

   categoryName: The name of the custom performance counter category to delete.
  """
  pass
 @staticmethod
 def Exists(categoryName,machineName=None):
  """
  Exists(categoryName: str,machineName: str) -> bool

  

   Determines whether the category is registered on the specified computer.

  

   categoryName: The name of the performance counter category to look for.

   machineName: The name of the computer to examine for the category.

   Returns: true if the category is registered; otherwise,false.

  Exists(categoryName: str) -> bool

  

   Determines whether the category is registered on the local computer.

  

   categoryName: The name of the performance counter category to look for.

   Returns: true if the category is registered; otherwise,false.
  """
  pass
 @staticmethod
 def GetCategories(machineName=None):
  """
  GetCategories(machineName: str) -> Array[PerformanceCounterCategory]

  

   Retrieves a list of the performance counter categories that are registered on the specified 

    computer.

  

  

   machineName: The computer to look on.

   Returns: An array of System.Diagnostics.PerformanceCounterCategory objects indicating the categories that 

    are registered on the specified computer.

  

  GetCategories() -> Array[PerformanceCounterCategory]

  

   Retrieves a list of the performance counter categories that are registered on the local computer.

   Returns: An array of System.Diagnostics.PerformanceCounterCategory objects indicating the categories that 

    are registered on the local computer.
  """
  pass
 def GetCounters(self,instanceName=None):
  """
  GetCounters(self: PerformanceCounterCategory,instanceName: str) -> Array[PerformanceCounter]

  

   Retrieves a list of the counters in a performance counter category that contains one or more 

    instances.

  

  

   instanceName: The performance object instance for which to retrieve the list of associated counters.

   Returns: An array of System.Diagnostics.PerformanceCounter objects indicating the counters that are 

    associated with the specified object instance of this performance counter category.

  

  GetCounters(self: PerformanceCounterCategory) -> Array[PerformanceCounter]

  

   Retrieves a list of the counters in a performance counter category that contains exactly one 

    instance.

  

   Returns: An array of System.Diagnostics.PerformanceCounter objects indicating the counters that are 

    associated with this single-instance performance counter category.
  """
  pass
 def GetInstanceNames(self):
  """
  GetInstanceNames(self: PerformanceCounterCategory) -> Array[str]

  

   Retrieves the list of performance object instances that are associated with this category.

   Returns: An array of strings representing the performance object instance names that are associated with 

    this category or,if the category contains only one performance object instance,a single-entry 

    array that contains an empty string ("").
  """
  pass
 def InstanceExists(self,instanceName,categoryName=None,machineName=None):
  """
  InstanceExists(instanceName: str,categoryName: str,machineName: str) -> bool

  

   Determines whether a specified category on a specified computer contains the specified 

    performance object instance.

  

  

   instanceName: The performance object instance to search for.

   categoryName: The performance counter category to search.

   machineName: The name of the computer on which to look for the category instance pair.

   Returns: true if the category contains the specified performance object instance; otherwise,false.

  InstanceExists(instanceName: str,categoryName: str) -> bool

  

   Determines whether a specified category on the local computer contains the specified performance 

    object instance.

  

  

   instanceName: The performance object instance to search for.

   categoryName: The performance counter category to search.

   Returns: true if the category contains the specified performance object instance; otherwise,false.

  InstanceExists(self: PerformanceCounterCategory,instanceName: str) -> bool

  

   Determines whether the specified performance object instance exists in the category that is 

    identified by this System.Diagnostics.PerformanceCounterCategory object's 

    System.Diagnostics.PerformanceCounterCategory.CategoryName property.

  

  

   instanceName: The performance object instance in this performance counter category to search for.

   Returns: true if the category contains the specified performance object instance; otherwise,false.
  """
  pass
 def ReadCategory(self):
  """
  ReadCategory(self: PerformanceCounterCategory) -> InstanceDataCollectionCollection

  

   Reads all the counter and performance object instance data that is associated with this 

    performance counter category.

  

   Returns: An System.Diagnostics.InstanceDataCollectionCollection that contains the counter and performance 

    object instance data for the category.
  """
  pass
 @staticmethod
 def __new__(self,categoryName=None,machineName=None):
  """
  __new__(cls: type)

  __new__(cls: type,categoryName: str)

  __new__(cls: type,categoryName: str,machineName: str)
  """
  pass
 CategoryHelp=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the category's help text.



Get: CategoryHelp(self: PerformanceCounterCategory) -> str



"""

 CategoryName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the performance object that defines this category.



Get: CategoryName(self: PerformanceCounterCategory) -> str



Set: CategoryName(self: PerformanceCounterCategory)=value

"""

 CategoryType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the performance counter category type.



Get: CategoryType(self: PerformanceCounterCategory) -> PerformanceCounterCategoryType



"""

 MachineName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the computer on which this category exists.



Get: MachineName(self: PerformanceCounterCategory) -> str



Set: MachineName(self: PerformanceCounterCategory)=value

"""





class MessageBoxIcon(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies constants defining which information to display.

 

 enum MessageBoxIcon,values: Asterisk (64),Error (16),Exclamation (48),Hand (16),Information (64),None (0),Question (32),Stop (16),Warning (48)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Asterisk=None
 Error=None
 Exclamation=None
 Hand=None
 Information=None
 None=None
 Question=None
 Stop=None
 value__=None
 Warning=None

